# pylint: disable=C0302,R0902,R0915
"Foundation Mercury Python API Client"

import decimal

import requests


def samples():
    "Sample API routes for testing"
    gets = [
        "/api/census2010/states",
        "/api/census2010/counties/12",
        "/api/census2010/tracts/12/001",
        "/api/census2010/blocks/12/001/000200",
        "/api/census2010/dp/12/001/000301",
        "/api/census2010/sf1basic/state/12/county/097",
        "/api/census2010/zcta5/12",
        "/api/census2010/sf1basic/state/12/zcta5/34746",
        "/api/census2010/sf1basic/state/12/county/001/tract/000301",
        "/api/census2010/sf1basic/state/12/county/001/tract/000200/block/1001",
        "/api/cities/FL",
        "/api/census2010/sf1/01/12/001/000200/1000",
        "/api/census2010/sf1/03/12/001/000200/1000",
        "/api/census2010/sf1/04/12/001/000200/1000",
        "/api/census2010/sf1/05/12/001/000200/1000",
        "/api/census2010/sf1/06/12/001/000200/1000",
        "/api/census2010/sf1/07/12/001/000200/1000",
        "/api/census2010/sf1/03/docs",
        "/api/geocode/770%20Maple%20Ridge%20Rd,Palm%20Harbor%20FL%2034683",
        "/api/neighborhood/1/census2010/tract",
        "/api/neighborhoods/state/FL/city/Kissimmee",
        "/api/neighborhood/10",
        "/api/revgeocode/28.08893740/-82.75338220"
    ]
    return gets


URL_BASE = "https://www.foundationmercury.com/api"
    

class CensusState():
    "A US State"
    def __init__(self, d=None):
        self.name = ""
        self.state_abbrev = ""
        self.state_code = ""
        if d:
            self.name = d["name"]
            self.state_abbrev = d["state_abbrev"]
            self.state_code = d["state_code"]


class CensusCounty():
    "A US County or County Equivalent"
    def __init__(self, d=None):
        self.name = ""
        self.county_code = ""
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        if d is not None:
            self.name = d["name"]
            self.county_code = d["county_code"]
            self.lat = decimal.Decimal(d["lat"])
            self.lon = decimal.Decimal(d["lon"])


class CensusTract():
    "A census tract"
    def __init__(self, d=None):
        self.name = ""
        self.tract_code = ""
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        if d is not None:
            self.name = d["name"]
            self.tract_code = d["tract_code"]
            self.lat = decimal.Decimal(d["lat"])
            self.lon = decimal.Decimal(d["lon"])


class CensusBlock():
    "A census block"
    def __init__(self, d=None):
        self.name = ""
        self.block_code = ""
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        if d is not None:
            self.name = d["name"]
            self.block_code = d["block_code"]
            self.lat = decimal.Decimal(d["lat"])
            self.lon = decimal.Decimal(d["lon"])


class TractDemographicProfile(): #pylint:disable=R0902
    "Demographic Profile data for a single census tract"
    def __init__(self, d=None): #pylint:disable=R0915
        self.sex_age_total = 0
        self.sex_age_under_5 = 0
        self.sex_age_5_9 = 0
        self.sex_age_10_14 = 0
        self.sex_age_15_19 = 0
        self.sex_age_20_24 = 0
        self.sex_age_25_29 = 0
        self.sex_age_30_34 = 0
        self.sex_age_35_39 = 0
        self.sex_age_40_44 = 0
        self.sex_age_45_49 = 0
        self.sex_age_50_54 = 0
        self.sex_age_55_59 = 0
        self.sex_age_60_64 = 0
        self.sex_age_65_69 = 0
        self.sex_age_70_74 = 0
        self.sex_age_75_79 = 0
        self.sex_age_80_84 = 0
        self.sex_age_85_plus = 0
        self.sex_age_total_m = 0
        self.sex_age_under_5_m = 0
        self.sex_age_5_9_m = 0
        self.sex_age_10_14_m = 0
        self.sex_age_15_19_m = 0
        self.sex_age_20_24_m = 0
        self.sex_age_25_29_m = 0
        self.sex_age_30_34_m = 0
        self.sex_age_35_39_m = 0
        self.sex_age_40_44_m = 0
        self.sex_age_45_49_m = 0
        self.sex_age_50_54_m = 0
        self.sex_age_55_59_m = 0
        self.sex_age_60_64_m = 0
        self.sex_age_65_69_m = 0
        self.sex_age_70_74_m = 0
        self.sex_age_75_79_m = 0
        self.sex_age_80_84_m = 0
        self.sex_age_85_plus_m = 0
        self.sex_age_total_f = 0
        self.sex_age_under_5_f = 0
        self.sex_age_5_9_f = 0
        self.sex_age_10_14_f = 0
        self.sex_age_15_19_f = 0
        self.sex_age_20_24_f = 0
        self.sex_age_25_29_f = 0
        self.sex_age_30_34_f = 0
        self.sex_age_35_39_f = 0
        self.sex_age_40_44_f = 0
        self.sex_age_45_49_f = 0
        self.sex_age_50_54_f = 0
        self.sex_age_55_59_f = 0
        self.sex_age_60_64_f = 0
        self.sex_age_65_69_f = 0
        self.sex_age_70_74_f = 0
        self.sex_age_75_79_f = 0
        self.sex_age_80_84_f = 0
        self.sex_age_85_plus_f = 0
        self.median_age_both = 0
        self.median_age_m = 0
        self.median_age_f = 0
        self.sex_16_over_both = 0
        self.sex_16_over_m = 0
        self.sex_16_over_f = 0
        self.sex_18_over_both = 0
        self.sex_18_over_m = 0
        self.sex_18_over_f = 0
        self.sex_21_over_both = 0
        self.sex_21_over_m = 0
        self.sex_21_over_f = 0
        self.sex_62_over_both = 0
        self.sex_62_over_m = 0
        self.sex_62_over_f = 0
        self.sex_65_over_both = 0
        self.sex_65_over_m = 0
        self.sex_65_over_f = 0
        self.race_total = 0
        self.race_one = 0
        self.race_white = 0
        self.race_black = 0
        self.race_native = 0
        self.race_asian = 0
        self.race_asian_indian = 0
        self.race_chinese = 0
        self.race_filipino = 0
        self.race_japanese = 0
        self.race_korean = 0
        self.race_vietnamese = 0
        self.race_other_asian = 0
        self.race_pacific = 0
        self.race_native_hawaiian = 0
        self.race_guam = 0
        self.race_samoam = 0
        self.race_other_pacific = 0
        self.race_other = 0
        self.race_two = 0
        self.race_white_native = 0
        self.race_white_asian = 0
        self.race_white_black = 0
        self.race_white_other = 0
        self.race_white_alone = 0
        self.race_black_alone = 0
        self.race_native_alone = 0
        self.race_asian_alone = 0
        self.race_hawaiian_alone = 0
        self.race_other_alone = 0
        self.hisp_not_total = 0
        self.hisp = 0
        self.mexican = 0
        self.puerto_rican = 0
        self.cuban = 0
        self.other_hisp = 0
        self.not_hisp = 0
        self.hisp_race_total = 0
        self.hisp_race_h = 0
        self.hisp_race_h_white = 0
        self.hisp_race_h_black = 0
        self.hisp_race_h_native = 0
        self.hisp_race_h_asian = 0
        self.hisp_race_h_hawaiian = 0
        self.hisp_race_h_other = 0
        self.hisp_race_h_two = 0
        self.hisp_race_noth = 0
        self.hisp_race_noth_white = 0
        self.hisp_race_noth_black = 0
        self.hisp_race_noth_native = 0
        self.hisp_race_noth_asian = 0
        self.hisp_race_noth_hawaiian = 0
        self.hisp_race_noth_other = 0
        self.hisp_race_noth_two = 0
        self.rel_total = 0
        self.rel_house = 0
        self.rel_house_holder = 0
        self.rel_house_spouse = 0
        self.rel_house_child = 0
        self.rel_house_child_18 = 0
        self.rel_house_other = 0
        self.rel_house_other_18 = 0
        self.rel_house_other_65 = 0
        self.rel_house_nonrel = 0
        self.rel_house_nonrel_18 = 0
        self.rel_house_nonrel_65 = 0
        self.rel_house_nonrel_unmp = 0
        self.rel_group = 0
        self.rel_group_inst = 0
        self.rel_group_inst_m = 0
        self.rel_group_inst_f = 0
        self.rel_group_noninst = 0
        self.rel_group_noninst_m = 0
        self.rel_group_noninst_f = 0
        self.house_total = 0
        self.house_family = 0
        self.house_family_18 = 0
        self.house_family_hw = 0
        self.house_family_hw_18 = 0
        self.house_family_m = 0
        self.house_family_m_18 = 0
        self.house_family_f = 0
        self.house_family_f_18 = 0
        self.house_nonfam = 0
        self.house_nonfam_alone = 0
        self.house_nonfam_m = 0
        self.house_nonfam_m_65 = 0
        self.house_nonfam_f = 0
        self.house_nonfam_f_65 = 0
        self.house_18 = 0
        self.house_65 = 0
        self.avg_house_size = decimal.Decimal(0)
        self.avg_fam_size = decimal.Decimal(0)
        self.occu_total = 0
        self.occu_occu = 0
        self.occu_vacant = 0
        self.occu_vacant_for_rent = 0
        self.occu_vacant_rented = 0
        self.occu_vacant_sale_only = 0
        self.occu_vacant_sold = 0
        self.occu_vacant_seasonal = 0
        self.occu_vacant_other = 0
        self.homeowner_vacany_rate = decimal.Decimal(0)
        self.rental_vacancy_rate = decimal.Decimal(0)
        self.tenure_total = 0
        self.tenure_owner = 0
        self.tenure_renter = 0
        self.pop_tenure_owner = 0
        self.pop_tenure_renter = 0
        self.avg_house_size_owner = decimal.Decimal(0)
        self.avg_house_size_renter = decimal.Decimal(0)
        if d is not None:
            self.sex_age_total = d["sex_age_total"]
            self.sex_age_under_5 = d["sex_age_under_5"]
            self.sex_age_5_9 = d["sex_age_5_9"]
            self.sex_age_10_14 = d["sex_age_10_14"]
            self.sex_age_15_19 = d["sex_age_15_19"]
            self.sex_age_20_24 = d["sex_age_20_24"]
            self.sex_age_25_29 = d["sex_age_25_29"]
            self.sex_age_30_34 = d["sex_age_30_34"]
            self.sex_age_35_39 = d["sex_age_35_39"]
            self.sex_age_40_44 = d["sex_age_40_44"]
            self.sex_age_45_49 = d["sex_age_45_49"]
            self.sex_age_50_54 = d["sex_age_50_54"]
            self.sex_age_55_59 = d["sex_age_55_59"]
            self.sex_age_60_64 = d["sex_age_60_64"]
            self.sex_age_65_69 = d["sex_age_65_69"]
            self.sex_age_70_74 = d["sex_age_70_74"]
            self.sex_age_75_79 = d["sex_age_75_79"]
            self.sex_age_80_84 = d["sex_age_80_84"]
            self.sex_age_85_plus = d["sex_age_85_plus"]
            self.sex_age_total_m = d["sex_age_total_m"]
            self.sex_age_under_5_m = d["sex_age_under_5_m"]
            self.sex_age_5_9_m = d["sex_age_5_9_m"]
            self.sex_age_10_14_m = d["sex_age_10_14_m"]
            self.sex_age_15_19_m = d["sex_age_15_19_m"]
            self.sex_age_20_24_m = d["sex_age_20_24_m"]
            self.sex_age_25_29_m = d["sex_age_25_29_m"]
            self.sex_age_30_34_m = d["sex_age_30_34_m"]
            self.sex_age_35_39_m = d["sex_age_35_39_m"]
            self.sex_age_40_44_m = d["sex_age_40_44_m"]
            self.sex_age_45_49_m = d["sex_age_45_49_m"]
            self.sex_age_50_54_m = d["sex_age_50_54_m"]
            self.sex_age_55_59_m = d["sex_age_55_59_m"]
            self.sex_age_60_64_m = d["sex_age_60_64_m"]
            self.sex_age_65_69_m = d["sex_age_65_69_m"]
            self.sex_age_70_74_m = d["sex_age_70_74_m"]
            self.sex_age_75_79_m = d["sex_age_75_79_m"]
            self.sex_age_80_84_m = d["sex_age_80_84_m"]
            self.sex_age_85_plus_m = d["sex_age_85_plus_m"]
            self.sex_age_total_f = d["sex_age_total_f"]
            self.sex_age_under_5_f = d["sex_age_under_5_f"]
            self.sex_age_5_9_f = d["sex_age_5_9_f"]
            self.sex_age_10_14_f = d["sex_age_10_14_f"]
            self.sex_age_15_19_f = d["sex_age_15_19_f"]
            self.sex_age_20_24_f = d["sex_age_20_24_f"]
            self.sex_age_25_29_f = d["sex_age_25_29_f"]
            self.sex_age_30_34_f = d["sex_age_30_34_f"]
            self.sex_age_35_39_f = d["sex_age_35_39_f"]
            self.sex_age_40_44_f = d["sex_age_40_44_f"]
            self.sex_age_45_49_f = d["sex_age_45_49_f"]
            self.sex_age_50_54_f = d["sex_age_50_54_f"]
            self.sex_age_55_59_f = d["sex_age_55_59_f"]
            self.sex_age_60_64_f = d["sex_age_60_64_f"]
            self.sex_age_65_69_f = d["sex_age_65_69_f"]
            self.sex_age_70_74_f = d["sex_age_70_74_f"]
            self.sex_age_75_79_f = d["sex_age_75_79_f"]
            self.sex_age_80_84_f = d["sex_age_80_84_f"]
            self.sex_age_85_plus_f = d["sex_age_85_plus_f"]
            self.median_age_both = d["median_age_both"]
            self.median_age_m = d["median_age_m"]
            self.median_age_f = d["median_age_f"]
            self.sex_16_over_both = d["sex_16_over_both"]
            self.sex_16_over_m = d["sex_16_over_m"]
            self.sex_16_over_f = d["sex_16_over_f"]
            self.sex_18_over_both = d["sex_18_over_both"]
            self.sex_18_over_m = d["sex_18_over_m"]
            self.sex_18_over_f = d["sex_18_over_f"]
            self.sex_21_over_both = d["sex_21_over_both"]
            self.sex_21_over_m = d["sex_21_over_m"]
            self.sex_21_over_f = d["sex_21_over_f"]
            self.sex_62_over_both = d["sex_62_over_both"]
            self.sex_62_over_m = d["sex_62_over_m"]
            self.sex_62_over_f = d["sex_62_over_f"]
            self.sex_65_over_both = d["sex_65_over_both"]
            self.sex_65_over_m = d["sex_65_over_m"]
            self.sex_65_over_f = d["sex_65_over_f"]
            self.race_total = d["race_total"]
            self.race_one = d["race_one"]
            self.race_white = d["race_white"]
            self.race_black = d["race_black"]
            self.race_native = d["race_native"]
            self.race_asian = d["race_asian"]
            self.race_asian_indian = d["race_asian_indian"]
            self.race_chinese = d["race_chinese"]
            self.race_filipino = d["race_filipino"]
            self.race_japanese = d["race_japanese"]
            self.race_korean = d["race_korean"]
            self.race_vietnamese = d["race_vietnamese"]
            self.race_other_asian = d["race_other_asian"]
            self.race_pacific = d["race_pacific"]
            self.race_native_hawaiian = d["race_native_hawaiian"]
            self.race_guam = d["race_guam"]
            self.race_samoam = d["race_samoam"]
            self.race_other_pacific = d["race_other_pacific"]
            self.race_other = d["race_other"]
            self.race_two = d["race_two"]
            self.race_white_native = d["race_white_native"]
            self.race_white_asian = d["race_white_asian"]
            self.race_white_black = d["race_white_black"]
            self.race_white_other = d["race_white_other"]
            self.race_white_alone = d["race_white_alone"]
            self.race_black_alone = d["race_black_alone"]
            self.race_native_alone = d["race_native_alone"]
            self.race_asian_alone = d["race_asian_alone"]
            self.race_hawaiian_alone = d["race_hawaiian_alone"]
            self.race_other_alone = d["race_other_alone"]
            self.hisp_not_total = d["hisp_not_total"]
            self.hisp = d["hisp"]
            self.mexican = d["mexican"]
            self.puerto_rican = d["puerto_rican"]
            self.cuban = d["cuban"]
            self.other_hisp = d["other_hisp"]
            self.not_hisp = d["not_hisp"]
            self.hisp_race_total = d["hisp_race_total"]
            self.hisp_race_h = d["hisp_race_h"]
            self.hisp_race_h_white = d["hisp_race_h_white"]
            self.hisp_race_h_black = d["hisp_race_h_black"]
            self.hisp_race_h_native = d["hisp_race_h_native"]
            self.hisp_race_h_asian = d["hisp_race_h_asian"]
            self.hisp_race_h_hawaiian = d["hisp_race_h_hawaiian"]
            self.hisp_race_h_other = d["hisp_race_h_other"]
            self.hisp_race_h_two = d["hisp_race_h_two"]
            self.hisp_race_noth = d["hisp_race_noth"]
            self.hisp_race_noth_white = d["hisp_race_noth_white"]
            self.hisp_race_noth_black = d["hisp_race_noth_black"]
            self.hisp_race_noth_native = d["hisp_race_noth_native"]
            self.hisp_race_noth_asian = d["hisp_race_noth_asian"]
            self.hisp_race_noth_hawaiian = d["hisp_race_noth_hawaiian"]
            self.hisp_race_noth_other = d["hisp_race_noth_other"]
            self.hisp_race_noth_two = d["hisp_race_noth_two"]
            self.rel_total = d["rel_total"]
            self.rel_house = d["rel_house"]
            self.rel_house_holder = d["rel_house_holder"]
            self.rel_house_spouse = d["rel_house_spouse"]
            self.rel_house_child = d["rel_house_child"]
            self.rel_house_child_18 = d["rel_house_child_18"]
            self.rel_house_other = d["rel_house_other"]
            self.rel_house_other_18 = d["rel_house_other_18"]
            self.rel_house_other_65 = d["rel_house_other_65"]
            self.rel_house_nonrel = d["rel_house_nonrel"]
            self.rel_house_nonrel_18 = d["rel_house_nonrel_18"]
            self.rel_house_nonrel_65 = d["rel_house_nonrel_65"]
            self.rel_house_nonrel_unmp = d["rel_house_nonrel_unmp"]
            self.rel_group = d["rel_group"]
            self.rel_group_inst = d["rel_group_inst"]
            self.rel_group_inst_m = d["rel_group_inst_m"]
            self.rel_group_inst_f = d["rel_group_inst_f"]
            self.rel_group_noninst = d["rel_group_noninst"]
            self.rel_group_noninst_m = d["rel_group_noninst_m"]
            self.rel_group_noninst_f = d["rel_group_noninst_f"]
            self.house_total = d["house_total"]
            self.house_family = d["house_family"]
            self.house_family_18 = d["house_family_18"]
            self.house_family_hw = d["house_family_hw"]
            self.house_family_hw_18 = d["house_family_hw_18"]
            self.house_family_m = d["house_family_m"]
            self.house_family_m_18 = d["house_family_m_18"]
            self.house_family_f = d["house_family_f"]
            self.house_family_f_18 = d["house_family_f_18"]
            self.house_nonfam = d["house_nonfam"]
            self.house_nonfam_alone = d["house_nonfam_alone"]
            self.house_nonfam_m = d["house_nonfam_m"]
            self.house_nonfam_m_65 = d["house_nonfam_m_65"]
            self.house_nonfam_f = d["house_nonfam_f"]
            self.house_nonfam_f_65 = d["house_nonfam_f_65"]
            self.house_18 = d["house_18"]
            self.house_65 = d["house_65"]
            self.avg_house_size = d["avg_house_size"]
            self.avg_fam_size = d["avg_fam_size"]
            self.occu_total = d["occu_total"]
            self.occu_occu = d["occu_occu"]
            self.occu_vacant = d["occu_vacant"]
            self.occu_vacant_for_rent = d["occu_vacant_for_rent"]
            self.occu_vacant_rented = d["occu_vacant_rented"]
            self.occu_vacant_sale_only = d["occu_vacant_sale_only"]
            self.occu_vacant_sold = d["occu_vacant_sold"]
            self.occu_vacant_seasonal = d["occu_vacant_seasonal"]
            self.occu_vacant_other = d["occu_vacant_other"]
            self.homeowner_vacany_rate = d["homeowner_vacany_rate"]
            self.rental_vacancy_rate = d["rental_vacancy_rate"]
            self.tenure_total = d["tenure_total"]
            self.tenure_owner = d["tenure_owner"]
            self.tenure_renter = d["tenure_renter"]
            self.pop_tenure_owner = d["pop_tenure_owner"]
            self.pop_tenure_renter = d["pop_tenure_renter"]
            self.avg_house_size_owner = d["avg_house_size_owner"]
            self.avg_house_size_renter = d["avg_house_size_renter"]


class BasicDemographics(): # pylint: disable=R0902
    "Selected demographic fields taken from various census files"
    def __init__(self, d=None): # pylint: disable=R0915
        self.state_abbrev = ""
        self.state_code = ""
        self.state_name = ""
        self.county_code = ""
        self.county_name = ""
        self.tract_code = ""
        self.block_code = ""
        self.zcta5 = ""
        self.geo_name = ""
        self.square_miles = decimal.Decimal(0)
        self.housing_units = 0
        self.total_population = 0
        self.population_density = decimal.Decimal(0)
        self.white = 0
        self.white_pct = decimal.Decimal(0)
        self.black = 0
        self.black_pct = decimal.Decimal(0)
        self.native = 0
        self.native_pct = decimal.Decimal(0)
        self.asian = 0
        self.asian_pct = decimal.Decimal(0)
        self.hawaiian = 0
        self.hawaiian_pct = decimal.Decimal(0)
        self.other = 0
        self.other_pct = decimal.Decimal(0)
        self.two_or_more = 0
        self.two_or_more_pct = decimal.Decimal(0)
        self.not_hisplatino = 0
        self.not_hisplatino_pct = decimal.Decimal(0)
        self.hisplatino = 0
        self.hisplatino_pct = decimal.Decimal(0)
        self.males = 0
        self.males_pct = decimal.Decimal(0)
        self.females = 0
        self.females_pct = decimal.Decimal(0)
        self.age_median = decimal.Decimal(0)
        self.age_median_male = decimal.Decimal(0)
        self.age_median_female = decimal.Decimal(0)
        self.house_1male = 0
        self.house_1male_pct = decimal.Decimal(0)
        self.house_1female = 0
        self.house_1female_pct = decimal.Decimal(0)
        self.house_family = 0
        self.house_family_pct = decimal.Decimal(0)
        self.house_husbwife = 0
        self.house_husbwife_pct = decimal.Decimal(0)
        self.households = 0
        if d is not None:
            self.state_abbrev = d["state_abbrev"]
            self.state_code = d["state_code"]
            self.state_name = d["state_name"]
            self.county_code = d["county_code"]
            self.county_name = d["county_name"]
            self.tract_code = d["tract_code"]
            self.block_code = d["block_code"]
            self.zcta5 = d["zcta5"]
            self.geo_name = d["geo_name"]
            self.square_miles = d["square_miles"]
            self.housing_units = d["housing_units"]
            self.total_population = d["total_population"]
            self.population_density = d["population_density"]
            self.white = d["white"]
            self.white_pct = d["white_pct"]
            self.black = d["black"]
            self.black_pct = d["black_pct"]
            self.native = d["native"]
            self.native_pct = d["native_pct"]
            self.asian = d["asian"]
            self.asian_pct = d["asian_pct"]
            self.hawaiian = d["hawaiian"]
            self.hawaiian_pct = d["hawaiian_pct"]
            self.other = d["other"]
            self.other_pct = d["other_pct"]
            self.two_or_more = d["two_or_more"]
            self.two_or_more_pct = d["two_or_more_pct"]
            self.not_hisplatino = d["not_hisplatino"]
            self.not_hisplatino_pct = d["not_hisplatino_pct"]
            self.hisplatino = d["hisplatino"]
            self.hisplatino_pct = d["hisplatino_pct"]
            self.males = d["males"]
            self.males_pct = d["males_pct"]
            self.females = d["females"]
            self.females_pct = d["females_pct"]
            self.age_median = d["age_median"]
            self.age_median_male = d["age_median_male"]
            self.age_median_female = d["age_median_female"]
            self.house_1male = d["house_1male"]
            self.house_1male_pct = d["house_1male_pct"]
            self.house_1female = d["house_1female"]
            self.house_1female_pct = d["house_1female_pct"]
            self.house_family = d["house_family"]
            self.house_family_pct = d["house_family_pct"]
            self.house_husbwife = d["house_husbwife"]
            self.house_husbwife_pct = d["house_husbwife_pct"]
            self.households = d["households"]

class Zcta:
    "A Zip Code Tabulation Area"
    def __init__(self, d=None):
        self.zcta = ""
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        if d is not None:
            self.zcta = d["zcta"]
            self.lat = d["lat"]
            self.lon = d["lon"]


class SF101():
    "Census SF1 File 01"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.total_population = 0
        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.total_population = d["total_population"]


class SF103():
    "Census SF1 File 03"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.racepop_total = 0
        self.racepop_white_alone = 0
        self.racepop_black_alone = 0
        self.racepop_native_alone = 0
        self.racepop_asian_alone = 0
        self.racepop_hawaiian_alone = 0
        self.racepop_other_alone = 0
        self.racepop_two_or_more = 0
        self.hspor_total = 0
        self.hspor_not = 0
        self.hspor_latino = 0
        self.hspra_total = 0
        self.hspra_not = 0
        self.hspra_not_white = 0
        self.hspra_not_black = 0
        self.hspra_not_native = 0
        self.hspra_not_asian = 0
        self.hspra_not_hawaiian = 0
        self.hspra_not_other = 0
        self.hspra_not_two = 0
        self.hspra_hsp = 0
        self.hspra_white = 0
        self.hspra_black = 0
        self.hspra_native = 0
        self.hspra_asian = 0
        self.hspra_hawaiian = 0
        self.hspra_other = 0
        self.hspra_two = 0
        self.racepop_tally_total = 0
        self.racepop_tally_white = 0
        self.racepop_tally_black = 0
        self.racepop_tally_native = 0
        self.racepop_tally_asian = 0
        self.racepop_tally_hawaiian = 0
        self.racepop_tally_other = 0
        self.hsp_tally_total = 0
        self.hsp_tally_not = 0
        self.hsp_tally_notw = 0
        self.hsp_tally_notb = 0
        self.hsp_tally_notn = 0
        self.hsp_tally_nota = 0
        self.hsp_tally_noth = 0
        self.hsp_tally_noto = 0
        self.hsp_tally = 0
        self.hsp_tally_w = 0
        self.hsp_tally_b = 0
        self.hsp_tally_n = 0
        self.hsp_tally_a = 0
        self.hsp_tally_h = 0
        self.hsp_tally_o = 0
        self.racepop_totaln = 0
        self.racepop_1 = 0
        self.racepop_1w = 0
        self.racepop_1b = 0
        self.racepop_1n = 0
        self.racepop_1a = 0
        self.racepop_1h = 0
        self.racepop_1o = 0
        self.racepop_2m = 0
        self.racepop_2 = 0
        self.racepop_2wb = 0
        self.racepop_2wn = 0
        self.racepop_2wa = 0
        self.racepop_2wh = 0
        self.racepop_2wo = 0
        self.racepop_2bn = 0
        self.racepop_2ba = 0
        self.racepop_2bh = 0
        self.racepop_2bo = 0
        self.racepop_2na = 0
        self.racepop_2nh = 0
        self.racepop_2no = 0
        self.racepop_2ah = 0
        self.racepop_2ao = 0
        self.racepop_2ho = 0
        self.racepop_3 = 0
        self.racepop_3wbn = 0
        self.racepop_3wba = 0
        self.racepop_3wbh = 0
        self.racepop_3wbo = 0
        self.racepop_3wna = 0
        self.racepop_3wnh = 0
        self.racepop_3wno = 0
        self.racepop_3wah = 0
        self.racepop_3wao = 0
        self.racepop_3who = 0
        self.racepop_3bna = 0
        self.racepop_3bnh = 0
        self.racepop_3bno = 0
        self.racepop_3bah = 0
        self.racepop_3bao = 0
        self.racepop_3bho = 0
        self.racepop_3nah = 0
        self.racepop_3nao = 0
        self.racepop_3nho = 0
        self.racepop_3aho = 0
        self.racepop_4 = 0
        self.racepop_4wbna = 0
        self.racepop_4wbnh = 0
        self.racepop_4wbno = 0
        self.racepop_4wbah = 0
        self.racepop_4wbao = 0
        self.racepop_4wbho = 0
        self.racepop_4wnah = 0
        self.racepop_4wnao = 0
        self.racepop_4wnho = 0
        self.racepop_4waho = 0
        self.racepop_4bnah = 0
        self.racepop_4bnao = 0
        self.racepop_4bnho = 0
        self.racepop_4baho = 0
        self.racepop_4naho = 0
        self.racepop_5 = 0
        self.racepop_5wbnah = 0
        self.racepop_5wbnao = 0
        self.racepop_5wbnho = 0
        self.racepop_5wbaho = 0
        self.racepop_5wnaho = 0
        self.racepop_5bnaho = 0
        self.racepop_6 = 0
        self.racepop_6wbnaho = 0
        self.hspnot_total = 0
        self.hspnot_h_total = 0
        self.hspnot_n = 0
        self.hspnot_n1 = 0
        self.hspnot_n1w = 0
        self.hspnot_n1b = 0
        self.hspnot_n1n = 0
        self.hspnot_n1a = 0
        self.hspnot_n1h = 0
        self.hspnot_n1o = 0
        self.hspnot_n2m = 0
        self.hspnot_n2 = 0
        self.hspnot_n2wb = 0
        self.hspnot_n2wn = 0
        self.hspnot_n2wa = 0
        self.hspnot_n2wh = 0
        self.hspnot_n2wo = 0
        self.hspnot_n2bn = 0
        self.hspnot_n2ba = 0
        self.hspnot_n2bh = 0
        self.hspnot_n2bo = 0
        self.hspnot_n2na = 0
        self.hspnot_n2nh = 0
        self.hspnot_n2no = 0
        self.hspnot_n2ah = 0
        self.hspnot_n2ao = 0
        self.hspnot_n2ho = 0
        self.hspnot_n3 = 0
        self.hspnot_n3wbn = 0
        self.hspnot_n3wba = 0
        self.hspnot_n3wbh = 0
        self.hspnot_n3wbo = 0
        self.hspnot_n3wna = 0
        self.hspnot_n3wnh = 0
        self.hspnot_n3wno = 0
        self.hspnot_n3wah = 0
        self.hspnot_n3wao = 0
        self.hspnot_n3who = 0
        self.hspnot_n3bna = 0
        self.hspnot_n3bnh = 0
        self.hspnot_n3bno = 0
        self.hspnot_n3bah = 0
        self.hspnot_n3bao = 0
        self.hspnot_n3bho = 0
        self.hspnot_n3nah = 0
        self.hspnot_n3nao = 0
        self.hspnot_n3nho = 0
        self.hspnot_n3aho = 0
        self.hspnot_n4 = 0
        self.hspnot_n4wbna = 0
        self.hspnot_n4wbnh = 0
        self.hspnot_n4wbno = 0
        self.hspnot_n4wbah = 0
        self.hspnot_n4wbao = 0
        self.hspnot_n4wbho = 0
        self.hspnot_n4wnah = 0
        self.hspnot_n4wnao = 0
        self.hspnot_n4wnho = 0
        self.hspnot_n4waho = 0
        self.hspnot_n4bnah = 0
        self.hspnot_n4bnao = 0
        self.hspnot_n4bnho = 0
        self.hspnot_n4baho = 0
        self.hspnot_n4naho = 0
        self.hspnot_n5 = 0
        self.hspnot_n5wbnah = 0
        self.hspnot_n5wbnao = 0
        self.hspnot_n5wbnho = 0
        self.hspnot_n5wbaho = 0
        self.hspnot_n5wnaho = 0
        self.hspnot_n5bnaho = 0
        self.hspnot_n6 = 0
        self.hspnot_n6wbnaho = 0

        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.racepop_total = d["racepop_total"]
            self.racepop_white_alone = d["racepop_white_alone"]
            self.racepop_black_alone = d["racepop_black_alone"]
            self.racepop_native_alone = d["racepop_native_alone"]
            self.racepop_asian_alone = d["racepop_asian_alone"]
            self.racepop_hawaiian_alone = d["racepop_hawaiian_alone"]
            self.racepop_other_alone = d["racepop_other_alone"]
            self.racepop_two_or_more = d["racepop_two_or_more"]
            self.hspor_total = d["hspor_total"]
            self.hspor_not = d["hspor_not"]
            self.hspor_latino = d["hspor_latino"]
            self.hspra_total = d["hspra_total"]
            self.hspra_not = d["hspra_not"]
            self.hspra_not_white = d["hspra_not_white"]
            self.hspra_not_black = d["hspra_not_black"]
            self.hspra_not_native = d["hspra_not_native"]
            self.hspra_not_asian = d["hspra_not_asian"]
            self.hspra_not_hawaiian = d["hspra_not_hawaiian"]
            self.hspra_not_other = d["hspra_not_other"]
            self.hspra_not_two = d["hspra_not_two"]
            self.hspra_hsp = d["hspra_hsp"]
            self.hspra_white = d["hspra_white"]
            self.hspra_black = d["hspra_black"]
            self.hspra_native = d["hspra_native"]
            self.hspra_asian = d["hspra_asian"]
            self.hspra_hawaiian = d["hspra_hawaiian"]
            self.hspra_other = d["hspra_other"]
            self.hspra_two = d["hspra_two"]
            self.racepop_tally_total = d["racepop_tally_total"]
            self.racepop_tally_white = d["racepop_tally_white"]
            self.racepop_tally_black = d["racepop_tally_black"]
            self.racepop_tally_native = d["racepop_tally_native"]
            self.racepop_tally_asian = d["racepop_tally_asian"]
            self.racepop_tally_hawaiian = d["racepop_tally_hawaiian"]
            self.racepop_tally_other = d["racepop_tally_other"]
            self.hsp_tally_total = d["hsp_tally_total"]
            self.hsp_tally_not = d["hsp_tally_not"]
            self.hsp_tally_notw = d["hsp_tally_notw"]
            self.hsp_tally_notb = d["hsp_tally_notb"]
            self.hsp_tally_notn = d["hsp_tally_notn"]
            self.hsp_tally_nota = d["hsp_tally_nota"]
            self.hsp_tally_noth = d["hsp_tally_noth"]
            self.hsp_tally_noto = d["hsp_tally_noto"]
            self.hsp_tally = d["hsp_tally"]
            self.hsp_tally_w = d["hsp_tally_w"]
            self.hsp_tally_b = d["hsp_tally_b"]
            self.hsp_tally_n = d["hsp_tally_n"]
            self.hsp_tally_a = d["hsp_tally_a"]
            self.hsp_tally_h = d["hsp_tally_h"]
            self.hsp_tally_o = d["hsp_tally_o"]
            self.racepop_totaln = d["racepop_totaln"]
            self.racepop_1 = d["racepop_1"]
            self.racepop_1w = d["racepop_1w"]
            self.racepop_1b = d["racepop_1b"]
            self.racepop_1n = d["racepop_1n"]
            self.racepop_1a = d["racepop_1a"]
            self.racepop_1h = d["racepop_1h"]
            self.racepop_1o = d["racepop_1o"]
            self.racepop_2m = d["racepop_2m"]
            self.racepop_2 = d["racepop_2"]
            self.racepop_2wb = d["racepop_2wb"]
            self.racepop_2wn = d["racepop_2wn"]
            self.racepop_2wa = d["racepop_2wa"]
            self.racepop_2wh = d["racepop_2wh"]
            self.racepop_2wo = d["racepop_2wo"]
            self.racepop_2bn = d["racepop_2bn"]
            self.racepop_2ba = d["racepop_2ba"]
            self.racepop_2bh = d["racepop_2bh"]
            self.racepop_2bo = d["racepop_2bo"]
            self.racepop_2na = d["racepop_2na"]
            self.racepop_2nh = d["racepop_2nh"]
            self.racepop_2no = d["racepop_2no"]
            self.racepop_2ah = d["racepop_2ah"]
            self.racepop_2ao = d["racepop_2ao"]
            self.racepop_2ho = d["racepop_2ho"]
            self.racepop_3 = d["racepop_3"]
            self.racepop_3wbn = d["racepop_3wbn"]
            self.racepop_3wba = d["racepop_3wba"]
            self.racepop_3wbh = d["racepop_3wbh"]
            self.racepop_3wbo = d["racepop_3wbo"]
            self.racepop_3wna = d["racepop_3wna"]
            self.racepop_3wnh = d["racepop_3wnh"]
            self.racepop_3wno = d["racepop_3wno"]
            self.racepop_3wah = d["racepop_3wah"]
            self.racepop_3wao = d["racepop_3wao"]
            self.racepop_3who = d["racepop_3who"]
            self.racepop_3bna = d["racepop_3bna"]
            self.racepop_3bnh = d["racepop_3bnh"]
            self.racepop_3bno = d["racepop_3bno"]
            self.racepop_3bah = d["racepop_3bah"]
            self.racepop_3bao = d["racepop_3bao"]
            self.racepop_3bho = d["racepop_3bho"]
            self.racepop_3nah = d["racepop_3nah"]
            self.racepop_3nao = d["racepop_3nao"]
            self.racepop_3nho = d["racepop_3nho"]
            self.racepop_3aho = d["racepop_3aho"]
            self.racepop_4 = d["racepop_4"]
            self.racepop_4wbna = d["racepop_4wbna"]
            self.racepop_4wbnh = d["racepop_4wbnh"]
            self.racepop_4wbno = d["racepop_4wbno"]
            self.racepop_4wbah = d["racepop_4wbah"]
            self.racepop_4wbao = d["racepop_4wbao"]
            self.racepop_4wbho = d["racepop_4wbho"]
            self.racepop_4wnah = d["racepop_4wnah"]
            self.racepop_4wnao = d["racepop_4wnao"]
            self.racepop_4wnho = d["racepop_4wnho"]
            self.racepop_4waho = d["racepop_4waho"]
            self.racepop_4bnah = d["racepop_4bnah"]
            self.racepop_4bnao = d["racepop_4bnao"]
            self.racepop_4bnho = d["racepop_4bnho"]
            self.racepop_4baho = d["racepop_4baho"]
            self.racepop_4naho = d["racepop_4naho"]
            self.racepop_5 = d["racepop_5"]
            self.racepop_5wbnah = d["racepop_5wbnah"]
            self.racepop_5wbnao = d["racepop_5wbnao"]
            self.racepop_5wbnho = d["racepop_5wbnho"]
            self.racepop_5wbaho = d["racepop_5wbaho"]
            self.racepop_5wnaho = d["racepop_5wnaho"]
            self.racepop_5bnaho = d["racepop_5bnaho"]
            self.racepop_6 = d["racepop_6"]
            self.racepop_6wbnaho = d["racepop_6wbnaho"]
            self.hspnot_total = d["hspnot_total"]
            self.hspnot_h_total = d["hspnot_h_total"]
            self.hspnot_n = d["hspnot_n"]
            self.hspnot_n1 = d["hspnot_n1"]
            self.hspnot_n1w = d["hspnot_n1w"]
            self.hspnot_n1b = d["hspnot_n1b"]
            self.hspnot_n1n = d["hspnot_n1n"]
            self.hspnot_n1a = d["hspnot_n1a"]
            self.hspnot_n1h = d["hspnot_n1h"]
            self.hspnot_n1o = d["hspnot_n1o"]
            self.hspnot_n2m = d["hspnot_n2m"]
            self.hspnot_n2 = d["hspnot_n2"]
            self.hspnot_n2wb = d["hspnot_n2wb"]
            self.hspnot_n2wn = d["hspnot_n2wn"]
            self.hspnot_n2wa = d["hspnot_n2wa"]
            self.hspnot_n2wh = d["hspnot_n2wh"]
            self.hspnot_n2wo = d["hspnot_n2wo"]
            self.hspnot_n2bn = d["hspnot_n2bn"]
            self.hspnot_n2ba = d["hspnot_n2ba"]
            self.hspnot_n2bh = d["hspnot_n2bh"]
            self.hspnot_n2bo = d["hspnot_n2bo"]
            self.hspnot_n2na = d["hspnot_n2na"]
            self.hspnot_n2nh = d["hspnot_n2nh"]
            self.hspnot_n2no = d["hspnot_n2no"]
            self.hspnot_n2ah = d["hspnot_n2ah"]
            self.hspnot_n2ao = d["hspnot_n2ao"]
            self.hspnot_n2ho = d["hspnot_n2ho"]
            self.hspnot_n3 = d["hspnot_n3"]
            self.hspnot_n3wbn = d["hspnot_n3wbn"]
            self.hspnot_n3wba = d["hspnot_n3wba"]
            self.hspnot_n3wbh = d["hspnot_n3wbh"]
            self.hspnot_n3wbo = d["hspnot_n3wbo"]
            self.hspnot_n3wna = d["hspnot_n3wna"]
            self.hspnot_n3wnh = d["hspnot_n3wnh"]
            self.hspnot_n3wno = d["hspnot_n3wno"]
            self.hspnot_n3wah = d["hspnot_n3wah"]
            self.hspnot_n3wao = d["hspnot_n3wao"]
            self.hspnot_n3who = d["hspnot_n3who"]
            self.hspnot_n3bna = d["hspnot_n3bna"]
            self.hspnot_n3bnh = d["hspnot_n3bnh"]
            self.hspnot_n3bno = d["hspnot_n3bno"]
            self.hspnot_n3bah = d["hspnot_n3bah"]
            self.hspnot_n3bao = d["hspnot_n3bao"]
            self.hspnot_n3bho = d["hspnot_n3bho"]
            self.hspnot_n3nah = d["hspnot_n3nah"]
            self.hspnot_n3nao = d["hspnot_n3nao"]
            self.hspnot_n3nho = d["hspnot_n3nho"]
            self.hspnot_n3aho = d["hspnot_n3aho"]
            self.hspnot_n4 = d["hspnot_n4"]
            self.hspnot_n4wbna = d["hspnot_n4wbna"]
            self.hspnot_n4wbnh = d["hspnot_n4wbnh"]
            self.hspnot_n4wbno = d["hspnot_n4wbno"]
            self.hspnot_n4wbah = d["hspnot_n4wbah"]
            self.hspnot_n4wbao = d["hspnot_n4wbao"]
            self.hspnot_n4wbho = d["hspnot_n4wbho"]
            self.hspnot_n4wnah = d["hspnot_n4wnah"]
            self.hspnot_n4wnao = d["hspnot_n4wnao"]
            self.hspnot_n4wnho = d["hspnot_n4wnho"]
            self.hspnot_n4waho = d["hspnot_n4waho"]
            self.hspnot_n4bnah = d["hspnot_n4bnah"]
            self.hspnot_n4bnao = d["hspnot_n4bnao"]
            self.hspnot_n4bnho = d["hspnot_n4bnho"]
            self.hspnot_n4baho = d["hspnot_n4baho"]
            self.hspnot_n4naho = d["hspnot_n4naho"]
            self.hspnot_n5 = d["hspnot_n5"]
            self.hspnot_n5wbnah = d["hspnot_n5wbnah"]
            self.hspnot_n5wbnao = d["hspnot_n5wbnao"]
            self.hspnot_n5wbnho = d["hspnot_n5wbnho"]
            self.hspnot_n5wbaho = d["hspnot_n5wbaho"]
            self.hspnot_n5wnaho = d["hspnot_n5wnaho"]
            self.hspnot_n5bnaho = d["hspnot_n5bnaho"]
            self.hspnot_n6 = d["hspnot_n6"]
            self.hspnot_n6wbnaho = d["hspnot_n6wbnaho"]


class SF104():
    "Census SF1 File 04"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.racepop_total_18p = 0
        self.racepop_1_18p = 0
        self.racepop_white_alone_18p = 0
        self.racepop_black_alone_18p = 0
        self.racepop_native_alone_18p = 0
        self.racepop_asian_alone_18p = 0
        self.racepop_hawaiian_alone_18p = 0
        self.racepop_other_alone_18p = 0
        self.racepop_2m_18p = 0
        self.racepop_2_18p = 0
        self.racepop_2wb_18p = 0
        self.racepop_2wn_18p = 0
        self.racepop_2wa_18p = 0
        self.racepop_2wh_18p = 0
        self.racepop_2wo_18p = 0
        self.racepop_2bn_18p = 0
        self.racepop_2ba_18p = 0
        self.racepop_2bh_18p = 0
        self.racepop_2bo_18p = 0
        self.racepop_2na_18p = 0
        self.racepop_2nh_18p = 0
        self.racepop_2no_18p = 0
        self.racepop_2ah_18p = 0
        self.racepop_2ao_18p = 0
        self.racepop_2ho_18p = 0
        self.racepop_3_18p = 0
        self.racepop_3wbn_18p = 0
        self.racepop_3wba_18p = 0
        self.racepop_3wbh_18p = 0
        self.racepop_3wbo_18p = 0
        self.racepop_3wna_18p = 0
        self.racepop_3wnh_18p = 0
        self.racepop_3wno_18p = 0
        self.racepop_3wah_18p = 0
        self.racepop_3wao_18p = 0
        self.racepop_3who_18p = 0
        self.racepop_3bna_18p = 0
        self.racepop_3bnh_18p = 0
        self.racepop_3bno_18p = 0
        self.racepop_3bah_18p = 0
        self.racepop_3bao_18p = 0
        self.racepop_3bho_18p = 0
        self.racepop_3nah_18p = 0
        self.racepop_3nao_18p = 0
        self.racepop_3nho_18p = 0
        self.racepop_3aho_18p = 0
        self.racepop_4_18p = 0
        self.racepop_4wbna_18p = 0
        self.racepop_4wbnh_18p = 0
        self.racepop_4wbno_18p = 0
        self.racepop_4wbah_18p = 0
        self.racepop_4wbao_18p = 0
        self.racepop_4wbho_18p = 0
        self.racepop_4wnah_18p = 0
        self.racepop_4wnao_18p = 0
        self.racepop_4wnho_18p = 0
        self.racepop_4waho_18p = 0
        self.racepop_4bnah_18p = 0
        self.racepop_4bnao_18p = 0
        self.racepop_4bnho_18p = 0
        self.racepop_4baho_18p = 0
        self.racepop_4naho_18p = 0
        self.racepop_5_18p = 0
        self.racepop_5wbnah_18p = 0
        self.racepop_5wbnao_18p = 0
        self.racepop_5wbnho_18p = 0
        self.racepop_5wbaho_18p = 0
        self.racepop_5wnaho_18p = 0
        self.racepop_5bnaho_18p = 0
        self.racepop_6_18p = 0
        self.racepop_6wbnaho_18p = 0
        self.hspnot_total_18p = 0
        self.hspnot_h_total_18p = 0
        self.hspnot_n_18p = 0
        self.hspnot_n1_18p = 0
        self.hspnot_n1w_18p = 0
        self.hspnot_n1b_18p = 0
        self.hspnot_n1n_18p = 0
        self.hspnot_n1a_18p = 0
        self.hspnot_n1h_18p = 0
        self.hspnot_n1o_18p = 0
        self.hspnot_n2m_18p = 0
        self.hspnot_n2_18p = 0
        self.hspnot_n2wb_18p = 0
        self.hspnot_n2wn_18p = 0
        self.hspnot_n2wa_18p = 0
        self.hspnot_n2wh_18p = 0
        self.hspnot_n2wo_18p = 0
        self.hspnot_n2bn_18p = 0
        self.hspnot_n2ba_18p = 0
        self.hspnot_n2bh_18p = 0
        self.hspnot_n2bo_18p = 0
        self.hspnot_n2na_18p = 0
        self.hspnot_n2nh_18p = 0
        self.hspnot_n2no_18p = 0
        self.hspnot_n2ah_18p = 0
        self.hspnot_n2ao_18p = 0
        self.hspnot_n2ho_18p = 0
        self.hspnot_n3_18p = 0
        self.hspnot_n3wbn_18p = 0
        self.hspnot_n3wba_18p = 0
        self.hspnot_n3wbh_18p = 0
        self.hspnot_n3wbo_18p = 0
        self.hspnot_n3wna_18p = 0
        self.hspnot_n3wnh_18p = 0
        self.hspnot_n3wno_18p = 0
        self.hspnot_n3wah_18p = 0
        self.hspnot_n3wao_18p = 0
        self.hspnot_n3who_18p = 0
        self.hspnot_n3bna_18p = 0
        self.hspnot_n3bnh_18p = 0
        self.hspnot_n3bno_18p = 0
        self.hspnot_n3bah_18p = 0
        self.hspnot_n3bao_18p = 0
        self.hspnot_n3bho_18p = 0
        self.hspnot_n3nah_18p = 0
        self.hspnot_n3nao_18p = 0
        self.hspnot_n3nho_18p = 0
        self.hspnot_n3aho_18p = 0
        self.hspnot_n4_18p = 0
        self.hspnot_n4wbna_18p = 0
        self.hspnot_n4wbnh_18p = 0
        self.hspnot_n4wbno_18p = 0
        self.hspnot_n4wbah_18p = 0
        self.hspnot_n4wbao_18p = 0
        self.hspnot_n4wbho_18p = 0
        self.hspnot_n4wnah_18p = 0
        self.hspnot_n4wnao_18p = 0
        self.hspnot_n4wnho_18p = 0
        self.hspnot_n4waho_18p = 0
        self.hspnot_n4bnah_18p = 0
        self.hspnot_n4bnao_18p = 0
        self.hspnot_n4bnho_18p = 0
        self.hspnot_n4baho_18p = 0
        self.hspnot_n4naho_18p = 0
        self.hspnot_n5_18p = 0
        self.hspnot_n5wbnah_18p = 0
        self.hspnot_n5wbnao_18p = 0
        self.hspnot_n5wbnho_18p = 0
        self.hspnot_n5wbaho_18p = 0
        self.hspnot_n5wnaho_18p = 0
        self.hspnot_n5bnaho_18p = 0
        self.hspnot_n6_18p = 0
        self.hspnot_n6wbnaho_18p = 0
        self.sex_age_total = 0
        self.sex_age_m = 0
        self.sex_age_m_u5 = 0
        self.sex_age_m_5_9 = 0
        self.sex_age_m_10_14 = 0
        self.sex_age_m_15_17 = 0
        self.sex_age_m_18_19 = 0
        self.sex_age_m_20 = 0
        self.sex_age_m_21 = 0
        self.sex_age_m_22_24 = 0
        self.sex_age_m_25_29 = 0
        self.sex_age_m_30_34 = 0
        self.sex_age_m_35_39 = 0
        self.sex_age_m_40_44 = 0
        self.sex_age_m_45_49 = 0
        self.sex_age_m_50_54 = 0
        self.sex_age_m_55_59 = 0
        self.sex_age_m_60_61 = 0
        self.sex_age_m_62_64 = 0
        self.sex_age_m_65_66 = 0
        self.sex_age_m_67_69 = 0
        self.sex_age_m_70_74 = 0
        self.sex_age_m_75_79 = 0
        self.sex_age_m_80_84 = 0
        self.sex_age_m_85o = 0
        self.sex_age_f = 0
        self.sex_age_f_u5 = 0
        self.sex_age_f_5_9 = 0
        self.sex_age_f_10_14 = 0
        self.sex_age_f_15_17 = 0
        self.sex_age_f_18_19 = 0
        self.sex_age_f_20 = 0
        self.sex_age_f_21 = 0
        self.sex_age_f_22_24 = 0
        self.sex_age_f_25_29 = 0
        self.sex_age_f_30_34 = 0
        self.sex_age_f_35_39 = 0
        self.sex_age_f_40_44 = 0
        self.sex_age_f_45_49 = 0
        self.sex_age_f_50_54 = 0
        self.sex_age_f_55_59 = 0
        self.sex_age_f_60_61 = 0
        self.sex_age_f_62_64 = 0
        self.sex_age_f_65_66 = 0
        self.sex_age_f_67_69 = 0
        self.sex_age_f_70_74 = 0
        self.sex_age_f_75_79 = 0
        self.sex_age_f_80_84 = 0
        self.sex_age_f_85o = 0
        self.sex_age_median_both = 0
        self.sex_age_median_m = 0
        self.sex_age_median_f = 0
        self.sex_age_total_u20 = 0
        self.sex_age_m_u20 = 0
        self.sex_age_m_u1 = 0
        self.sex_age_m_1 = 0
        self.sex_age_m_2 = 0
        self.sex_age_m_3 = 0
        self.sex_age_m_4 = 0
        self.sex_age_m_5 = 0
        self.sex_age_m_6 = 0
        self.sex_age_m_7 = 0
        self.sex_age_m_8 = 0
        self.sex_age_m_9 = 0
        self.sex_age_m_10 = 0
        self.sex_age_m_11 = 0
        self.sex_age_m_12 = 0
        self.sex_age_m_13 = 0
        self.sex_age_m_14 = 0
        self.sex_age_m_15 = 0
        self.sex_age_m_16 = 0
        self.sex_age_m_17 = 0
        self.sex_age_m_18 = 0
        self.sex_age_m_19 = 0
        self.sex_age_f_u20 = 0
        self.sex_age_f_u1 = 0
        self.sex_age_f_1 = 0
        self.sex_age_f_2 = 0
        self.sex_age_f_3 = 0
        self.sex_age_f_4 = 0
        self.sex_age_f_5 = 0
        self.sex_age_f_6 = 0
        self.sex_age_f_7 = 0
        self.sex_age_f_8 = 0
        self.sex_age_f_9 = 0
        self.sex_age_f_10 = 0
        self.sex_age_f_11 = 0
        self.sex_age_f_12 = 0
        self.sex_age_f_13 = 0
        self.sex_age_f_14 = 0
        self.sex_age_f_15 = 0
        self.sex_age_f_16 = 0
        self.sex_age_f_17 = 0
        self.sex_age_f_18 = 0
        self.sex_age_f_19 = 0

        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.racepop_total_18p = d["racepop_total_18p"]
            self.racepop_1_18p = d["racepop_1_18p"]
            self.racepop_white_alone_18p = d["racepop_white_alone_18p"]
            self.racepop_black_alone_18p = d["racepop_black_alone_18p"]
            self.racepop_native_alone_18p = d["racepop_native_alone_18p"]
            self.racepop_asian_alone_18p = d["racepop_asian_alone_18p"]
            self.racepop_hawaiian_alone_18p = d["racepop_hawaiian_alone_18p"]
            self.racepop_other_alone_18p = d["racepop_other_alone_18p"]
            self.racepop_2m_18p = d["racepop_2m_18p"]
            self.racepop_2_18p = d["racepop_2_18p"]
            self.racepop_2wb_18p = d["racepop_2wb_18p"]
            self.racepop_2wn_18p = d["racepop_2wn_18p"]
            self.racepop_2wa_18p = d["racepop_2wa_18p"]
            self.racepop_2wh_18p = d["racepop_2wh_18p"]
            self.racepop_2wo_18p = d["racepop_2wo_18p"]
            self.racepop_2bn_18p = d["racepop_2bn_18p"]
            self.racepop_2ba_18p = d["racepop_2ba_18p"]
            self.racepop_2bh_18p = d["racepop_2bh_18p"]
            self.racepop_2bo_18p = d["racepop_2bo_18p"]
            self.racepop_2na_18p = d["racepop_2na_18p"]
            self.racepop_2nh_18p = d["racepop_2nh_18p"]
            self.racepop_2no_18p = d["racepop_2no_18p"]
            self.racepop_2ah_18p = d["racepop_2ah_18p"]
            self.racepop_2ao_18p = d["racepop_2ao_18p"]
            self.racepop_2ho_18p = d["racepop_2ho_18p"]
            self.racepop_3_18p = d["racepop_3_18p"]
            self.racepop_3wbn_18p = d["racepop_3wbn_18p"]
            self.racepop_3wba_18p = d["racepop_3wba_18p"]
            self.racepop_3wbh_18p = d["racepop_3wbh_18p"]
            self.racepop_3wbo_18p = d["racepop_3wbo_18p"]
            self.racepop_3wna_18p = d["racepop_3wna_18p"]
            self.racepop_3wnh_18p = d["racepop_3wnh_18p"]
            self.racepop_3wno_18p = d["racepop_3wno_18p"]
            self.racepop_3wah_18p = d["racepop_3wah_18p"]
            self.racepop_3wao_18p = d["racepop_3wao_18p"]
            self.racepop_3who_18p = d["racepop_3who_18p"]
            self.racepop_3bna_18p = d["racepop_3bna_18p"]
            self.racepop_3bnh_18p = d["racepop_3bnh_18p"]
            self.racepop_3bno_18p = d["racepop_3bno_18p"]
            self.racepop_3bah_18p = d["racepop_3bah_18p"]
            self.racepop_3bao_18p = d["racepop_3bao_18p"]
            self.racepop_3bho_18p = d["racepop_3bho_18p"]
            self.racepop_3nah_18p = d["racepop_3nah_18p"]
            self.racepop_3nao_18p = d["racepop_3nao_18p"]
            self.racepop_3nho_18p = d["racepop_3nho_18p"]
            self.racepop_3aho_18p = d["racepop_3aho_18p"]
            self.racepop_4_18p = d["racepop_4_18p"]
            self.racepop_4wbna_18p = d["racepop_4wbna_18p"]
            self.racepop_4wbnh_18p = d["racepop_4wbnh_18p"]
            self.racepop_4wbno_18p = d["racepop_4wbno_18p"]
            self.racepop_4wbah_18p = d["racepop_4wbah_18p"]
            self.racepop_4wbao_18p = d["racepop_4wbao_18p"]
            self.racepop_4wbho_18p = d["racepop_4wbho_18p"]
            self.racepop_4wnah_18p = d["racepop_4wnah_18p"]
            self.racepop_4wnao_18p = d["racepop_4wnao_18p"]
            self.racepop_4wnho_18p = d["racepop_4wnho_18p"]
            self.racepop_4waho_18p = d["racepop_4waho_18p"]
            self.racepop_4bnah_18p = d["racepop_4bnah_18p"]
            self.racepop_4bnao_18p = d["racepop_4bnao_18p"]
            self.racepop_4bnho_18p = d["racepop_4bnho_18p"]
            self.racepop_4baho_18p = d["racepop_4baho_18p"]
            self.racepop_4naho_18p = d["racepop_4naho_18p"]
            self.racepop_5_18p = d["racepop_5_18p"]
            self.racepop_5wbnah_18p = d["racepop_5wbnah_18p"]
            self.racepop_5wbnao_18p = d["racepop_5wbnao_18p"]
            self.racepop_5wbnho_18p = d["racepop_5wbnho_18p"]
            self.racepop_5wbaho_18p = d["racepop_5wbaho_18p"]
            self.racepop_5wnaho_18p = d["racepop_5wnaho_18p"]
            self.racepop_5bnaho_18p = d["racepop_5bnaho_18p"]
            self.racepop_6_18p = d["racepop_6_18p"]
            self.racepop_6wbnaho_18p = d["racepop_6wbnaho_18p"]
            self.hspnot_total_18p = d["hspnot_total_18p"]
            self.hspnot_h_total_18p = d["hspnot_h_total_18p"]
            self.hspnot_n_18p = d["hspnot_n_18p"]
            self.hspnot_n1_18p = d["hspnot_n1_18p"]
            self.hspnot_n1w_18p = d["hspnot_n1w_18p"]
            self.hspnot_n1b_18p = d["hspnot_n1b_18p"]
            self.hspnot_n1n_18p = d["hspnot_n1n_18p"]
            self.hspnot_n1a_18p = d["hspnot_n1a_18p"]
            self.hspnot_n1h_18p = d["hspnot_n1h_18p"]
            self.hspnot_n1o_18p = d["hspnot_n1o_18p"]
            self.hspnot_n2m_18p = d["hspnot_n2m_18p"]
            self.hspnot_n2_18p = d["hspnot_n2_18p"]
            self.hspnot_n2wb_18p = d["hspnot_n2wb_18p"]
            self.hspnot_n2wn_18p = d["hspnot_n2wn_18p"]
            self.hspnot_n2wa_18p = d["hspnot_n2wa_18p"]
            self.hspnot_n2wh_18p = d["hspnot_n2wh_18p"]
            self.hspnot_n2wo_18p = d["hspnot_n2wo_18p"]
            self.hspnot_n2bn_18p = d["hspnot_n2bn_18p"]
            self.hspnot_n2ba_18p = d["hspnot_n2ba_18p"]
            self.hspnot_n2bh_18p = d["hspnot_n2bh_18p"]
            self.hspnot_n2bo_18p = d["hspnot_n2bo_18p"]
            self.hspnot_n2na_18p = d["hspnot_n2na_18p"]
            self.hspnot_n2nh_18p = d["hspnot_n2nh_18p"]
            self.hspnot_n2no_18p = d["hspnot_n2no_18p"]
            self.hspnot_n2ah_18p = d["hspnot_n2ah_18p"]
            self.hspnot_n2ao_18p = d["hspnot_n2ao_18p"]
            self.hspnot_n2ho_18p = d["hspnot_n2ho_18p"]
            self.hspnot_n3_18p = d["hspnot_n3_18p"]
            self.hspnot_n3wbn_18p = d["hspnot_n3wbn_18p"]
            self.hspnot_n3wba_18p = d["hspnot_n3wba_18p"]
            self.hspnot_n3wbh_18p = d["hspnot_n3wbh_18p"]
            self.hspnot_n3wbo_18p = d["hspnot_n3wbo_18p"]
            self.hspnot_n3wna_18p = d["hspnot_n3wna_18p"]
            self.hspnot_n3wnh_18p = d["hspnot_n3wnh_18p"]
            self.hspnot_n3wno_18p = d["hspnot_n3wno_18p"]
            self.hspnot_n3wah_18p = d["hspnot_n3wah_18p"]
            self.hspnot_n3wao_18p = d["hspnot_n3wao_18p"]
            self.hspnot_n3who_18p = d["hspnot_n3who_18p"]
            self.hspnot_n3bna_18p = d["hspnot_n3bna_18p"]
            self.hspnot_n3bnh_18p = d["hspnot_n3bnh_18p"]
            self.hspnot_n3bno_18p = d["hspnot_n3bno_18p"]
            self.hspnot_n3bah_18p = d["hspnot_n3bah_18p"]
            self.hspnot_n3bao_18p = d["hspnot_n3bao_18p"]
            self.hspnot_n3bho_18p = d["hspnot_n3bho_18p"]
            self.hspnot_n3nah_18p = d["hspnot_n3nah_18p"]
            self.hspnot_n3nao_18p = d["hspnot_n3nao_18p"]
            self.hspnot_n3nho_18p = d["hspnot_n3nho_18p"]
            self.hspnot_n3aho_18p = d["hspnot_n3aho_18p"]
            self.hspnot_n4_18p = d["hspnot_n4_18p"]
            self.hspnot_n4wbna_18p = d["hspnot_n4wbna_18p"]
            self.hspnot_n4wbnh_18p = d["hspnot_n4wbnh_18p"]
            self.hspnot_n4wbno_18p = d["hspnot_n4wbno_18p"]
            self.hspnot_n4wbah_18p = d["hspnot_n4wbah_18p"]
            self.hspnot_n4wbao_18p = d["hspnot_n4wbao_18p"]
            self.hspnot_n4wbho_18p = d["hspnot_n4wbho_18p"]
            self.hspnot_n4wnah_18p = d["hspnot_n4wnah_18p"]
            self.hspnot_n4wnao_18p = d["hspnot_n4wnao_18p"]
            self.hspnot_n4wnho_18p = d["hspnot_n4wnho_18p"]
            self.hspnot_n4waho_18p = d["hspnot_n4waho_18p"]
            self.hspnot_n4bnah_18p = d["hspnot_n4bnah_18p"]
            self.hspnot_n4bnao_18p = d["hspnot_n4bnao_18p"]
            self.hspnot_n4bnho_18p = d["hspnot_n4bnho_18p"]
            self.hspnot_n4baho_18p = d["hspnot_n4baho_18p"]
            self.hspnot_n4naho_18p = d["hspnot_n4naho_18p"]
            self.hspnot_n5_18p = d["hspnot_n5_18p"]
            self.hspnot_n5wbnah_18p = d["hspnot_n5wbnah_18p"]
            self.hspnot_n5wbnao_18p = d["hspnot_n5wbnao_18p"]
            self.hspnot_n5wbnho_18p = d["hspnot_n5wbnho_18p"]
            self.hspnot_n5wbaho_18p = d["hspnot_n5wbaho_18p"]
            self.hspnot_n5wnaho_18p = d["hspnot_n5wnaho_18p"]
            self.hspnot_n5bnaho_18p = d["hspnot_n5bnaho_18p"]
            self.hspnot_n6_18p = d["hspnot_n6_18p"]
            self.hspnot_n6wbnaho_18p = d["hspnot_n6wbnaho_18p"]
            self.sex_age_total = d["sex_age_total"]
            self.sex_age_m = d["sex_age_m"]
            self.sex_age_m_u5 = d["sex_age_m_u5"]
            self.sex_age_m_5_9 = d["sex_age_m_5_9"]
            self.sex_age_m_10_14 = d["sex_age_m_10_14"]
            self.sex_age_m_15_17 = d["sex_age_m_15_17"]
            self.sex_age_m_18_19 = d["sex_age_m_18_19"]
            self.sex_age_m_20 = d["sex_age_m_20"]
            self.sex_age_m_21 = d["sex_age_m_21"]
            self.sex_age_m_22_24 = d["sex_age_m_22_24"]
            self.sex_age_m_25_29 = d["sex_age_m_25_29"]
            self.sex_age_m_30_34 = d["sex_age_m_30_34"]
            self.sex_age_m_35_39 = d["sex_age_m_35_39"]
            self.sex_age_m_40_44 = d["sex_age_m_40_44"]
            self.sex_age_m_45_49 = d["sex_age_m_45_49"]
            self.sex_age_m_50_54 = d["sex_age_m_50_54"]
            self.sex_age_m_55_59 = d["sex_age_m_55_59"]
            self.sex_age_m_60_61 = d["sex_age_m_60_61"]
            self.sex_age_m_62_64 = d["sex_age_m_62_64"]
            self.sex_age_m_65_66 = d["sex_age_m_65_66"]
            self.sex_age_m_67_69 = d["sex_age_m_67_69"]
            self.sex_age_m_70_74 = d["sex_age_m_70_74"]
            self.sex_age_m_75_79 = d["sex_age_m_75_79"]
            self.sex_age_m_80_84 = d["sex_age_m_80_84"]
            self.sex_age_m_85o = d["sex_age_m_85o"]
            self.sex_age_f = d["sex_age_f"]
            self.sex_age_f_u5 = d["sex_age_f_u5"]
            self.sex_age_f_5_9 = d["sex_age_f_5_9"]
            self.sex_age_f_10_14 = d["sex_age_f_10_14"]
            self.sex_age_f_15_17 = d["sex_age_f_15_17"]
            self.sex_age_f_18_19 = d["sex_age_f_18_19"]
            self.sex_age_f_20 = d["sex_age_f_20"]
            self.sex_age_f_21 = d["sex_age_f_21"]
            self.sex_age_f_22_24 = d["sex_age_f_22_24"]
            self.sex_age_f_25_29 = d["sex_age_f_25_29"]
            self.sex_age_f_30_34 = d["sex_age_f_30_34"]
            self.sex_age_f_35_39 = d["sex_age_f_35_39"]
            self.sex_age_f_40_44 = d["sex_age_f_40_44"]
            self.sex_age_f_45_49 = d["sex_age_f_45_49"]
            self.sex_age_f_50_54 = d["sex_age_f_50_54"]
            self.sex_age_f_55_59 = d["sex_age_f_55_59"]
            self.sex_age_f_60_61 = d["sex_age_f_60_61"]
            self.sex_age_f_62_64 = d["sex_age_f_62_64"]
            self.sex_age_f_65_66 = d["sex_age_f_65_66"]
            self.sex_age_f_67_69 = d["sex_age_f_67_69"]
            self.sex_age_f_70_74 = d["sex_age_f_70_74"]
            self.sex_age_f_75_79 = d["sex_age_f_75_79"]
            self.sex_age_f_80_84 = d["sex_age_f_80_84"]
            self.sex_age_f_85o = d["sex_age_f_85o"]
            self.sex_age_median_both = d["sex_age_median_both"]
            self.sex_age_median_m = d["sex_age_median_m"]
            self.sex_age_median_f = d["sex_age_median_f"]
            self.sex_age_total_u20 = d["sex_age_total_u20"]
            self.sex_age_m_u20 = d["sex_age_m_u20"]
            self.sex_age_m_u1 = d["sex_age_m_u1"]
            self.sex_age_m_1 = d["sex_age_m_1"]
            self.sex_age_m_2 = d["sex_age_m_2"]
            self.sex_age_m_3 = d["sex_age_m_3"]
            self.sex_age_m_4 = d["sex_age_m_4"]
            self.sex_age_m_5 = d["sex_age_m_5"]
            self.sex_age_m_6 = d["sex_age_m_6"]
            self.sex_age_m_7 = d["sex_age_m_7"]
            self.sex_age_m_8 = d["sex_age_m_8"]
            self.sex_age_m_9 = d["sex_age_m_9"]
            self.sex_age_m_10 = d["sex_age_m_10"]
            self.sex_age_m_11 = d["sex_age_m_11"]
            self.sex_age_m_12 = d["sex_age_m_12"]
            self.sex_age_m_13 = d["sex_age_m_13"]
            self.sex_age_m_14 = d["sex_age_m_14"]
            self.sex_age_m_15 = d["sex_age_m_15"]
            self.sex_age_m_16 = d["sex_age_m_16"]
            self.sex_age_m_17 = d["sex_age_m_17"]
            self.sex_age_m_18 = d["sex_age_m_18"]
            self.sex_age_m_19 = d["sex_age_m_19"]
            self.sex_age_f_u20 = d["sex_age_f_u20"]
            self.sex_age_f_u1 = d["sex_age_f_u1"]
            self.sex_age_f_1 = d["sex_age_f_1"]
            self.sex_age_f_2 = d["sex_age_f_2"]
            self.sex_age_f_3 = d["sex_age_f_3"]
            self.sex_age_f_4 = d["sex_age_f_4"]
            self.sex_age_f_5 = d["sex_age_f_5"]
            self.sex_age_f_6 = d["sex_age_f_6"]
            self.sex_age_f_7 = d["sex_age_f_7"]
            self.sex_age_f_8 = d["sex_age_f_8"]
            self.sex_age_f_9 = d["sex_age_f_9"]
            self.sex_age_f_10 = d["sex_age_f_10"]
            self.sex_age_f_11 = d["sex_age_f_11"]
            self.sex_age_f_12 = d["sex_age_f_12"]
            self.sex_age_f_13 = d["sex_age_f_13"]
            self.sex_age_f_14 = d["sex_age_f_14"]
            self.sex_age_f_15 = d["sex_age_f_15"]
            self.sex_age_f_16 = d["sex_age_f_16"]
            self.sex_age_f_17 = d["sex_age_f_17"]
            self.sex_age_f_18 = d["sex_age_f_18"]
            self.sex_age_f_19 = d["sex_age_f_19"]


class SF105():
    "Census SF1 File 05"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.hsphse_total = 0
        self.hsphse_not = 0
        self.hsphse_notwhtal = 0
        self.hspse_notblkal = 0
        self.hsphse_notaianal = 0
        self.hsphse_notasial = 0
        self.hsphse_notnhopial = 0
        self.hsphse_notothal = 0
        self.hsphse_nottwoplus = 0
        self.hsphse_is = 0
        self.hsphse_whtal = 0
        self.hsphse_blkal = 0
        self.hsphse_aianal = 0
        self.hsphse_asial = 0
        self.hsphse_nhopial = 0
        self.hsphse_othal = 0
        self.hsphse_twoplus = 0
        self.popage_total = 0
        self.popage_und18 = 0
        self.popage_18plus = 0
        self.avghse_total = decimal.Decimal(0)
        self.avghse_und18 = decimal.Decimal(0)
        self.avghse_18plus = decimal.Decimal(0)
        self.hsetyp_total = 0
        self.hsetyp_fam = 0
        self.hsetyp_hwf = 0
        self.hsetyp_of = 0
        self.hsetyp_mh = 0
        self.hsetyp_fh = 0
        self.hsetyp_nfh = 0
        self.hsetyp_nfhal = 0
        self.hsetyp_nfhnotal = 0
        self.hseownchd_total = 0
        self.hseownchd_1h = 0
        self.hseownchd_1mh = 0
        self.hseownchd_1fh = 0
        self.hseownchd_2ph = 0
        self.hseownchd_famh = 0
        self.hseownchd_hwh = 0
        self.hseownchd_hwchd = 0
        self.hseownchd_hwnochd = 0
        self.hseownchd_of = 0
        self.hseownchd_ofm = 0
        self.hseownchd_ofmchd = 0
        self.hseownchd_ofmnochd = 0
        self.hseownchd_off = 0
        self.hseownchd_offchd = 0
        self.hseownchd_offnochd = 0
        self.hseownchd_nf = 0
        self.hseownchd_nfmh = 0
        self.hseownchd_nffh = 0
        self.hse18_total = 0
        self.hse18_with = 0
        self.hse18_fam = 0
        self.hse18_hwfam = 0
        self.hse18_hwund6 = 0
        self.hse18_hwund6to17 = 0
        self.hse18_hw6to17 = 0
        self.hse18_ofam = 0
        self.hse18_ofmh = 0
        self.hse18_omhund6 = 0
        self.hse18_omhund6to17 = 0
        self.hse18_omh6to17 = 0
        self.hse18_offh = 0
        self.hse18_ofwund6 = 0
        self.hse18_ofwund6to17 = 0
        self.hse18_ofw6to17 = 0
        self.hse18_nfam = 0
        self.hse18_nm = 0
        self.hse18_nmund6 = 0
        self.hse18_nmund6to17 = 0
        self.hse18_nm6to17 = 0
        self.hse18_nf = 0
        self.hse18_nfund6 = 0
        self.hse18_nfund6to17 = 0
        self.hse18_nf6to17 = 0
        self.hse18_not = 0
        self.hse18_notfam = 0
        self.hse18_nothwf = 0
        self.hse18_notof = 0
        self.hse18_notmh = 0
        self.hse18_notfh = 0
        self.hse18_notn = 0
        self.hse18_notnm = 0
        self.hse18_notnf = 0
        self.hsechd_total = 0
        self.hsechd_15to64 = 0
        self.hsechd_15to64f = 0
        self.hsechd_15to64hwf = 0
        self.hsechd_15to64hwfchd = 0
        self.hsechd_15to64hwfno = 0
        self.hsechd_15to64of = 0
        self.hsechd_15to64mh = 0
        self.hsechd_15to64mhchd = 0
        self.hsechd_15to64mhno = 0
        self.hsechd_15to64fh = 0
        self.hsechd_15to64fhchd = 0
        self.hsechd_15to64fhno = 0
        self.hsechd_15to64nf = 0
        self.hsechd_15to64nfal = 0
        self.hsechd_15to64nfnal = 0
        self.hsechd_65pl = 0
        self.hsechd_65plf = 0
        self.hsechd_65plhwf = 0
        self.hsechd_65plhwfchd = 0
        self.hsechd_65plhwfno = 0
        self.hsechd_65plof = 0
        self.hsechd_65plmh = 0
        self.hsechd_65plmhchd = 0
        self.hsechd_65plmhno = 0
        self.hsechd_65plfh = 0
        self.hsechd_65plfhchd = 0
        self.hsechd_65plfhno = 0
        self.hsechd_65plnf = 0
        self.hsechd_65plnfal = 0
        self.hsechd_65plnfnal = 0
        self.hsehld_total = 0
        self.hsehld_fam = 0
        self.hsehld_fam15to24 = 0
        self.hsehld_fam25to34 = 0
        self.hsehld_fam35to44 = 0
        self.hsehld_fam45to54 = 0
        self.hsehld_fam55to59 = 0
        self.hsehld_fam60to64 = 0
        self.hsehld_fam65to74 = 0
        self.hsehld_fam75to84 = 0
        self.hsehld_fam85 = 0
        self.hsehld_nonfam = 0
        self.hsehld_nonfam15to24 = 0
        self.hsehld_nonfam25to34 = 0
        self.hsehld_nonfam35to44 = 0
        self.hsehld_nonfam45to54 = 0
        self.hsehld_nonfam55to59 = 0
        self.hsehld_nonfam60to64 = 0
        self.hsehld_nonfam65to74 = 0
        self.hsehld_nonfam75to84 = 0
        self.hsehld_nonfam85 = 0
        self.hse60_total = 0
        self.hse60_w = 0
        self.hse60_wf = 0
        self.hse60_whw = 0
        self.hse60_wof = 0
        self.hse60_wofm = 0
        self.hse60_woff = 0
        self.hse60_wnf = 0
        self.hse60_n = 0
        self.hse60_nf = 0
        self.hse60_nhw = 0
        self.hse60_nof = 0
        self.hse60_nofm = 0
        self.hse60_noff = 0
        self.hse60_nnf = 0
        self.hse60sze_total = 0
        self.hse60sze_w = 0
        self.hse60sze_w1 = 0
        self.hse60sze_w2pls = 0
        self.hse60sze_w2plsf = 0
        self.hse60sze_w2plsnf = 0
        self.hse60sze_n = 0
        self.hse60sze_n1 = 0
        self.hse60sze_n2pls = 0
        self.hse60sze_n2plsf = 0
        self.hse60sze_n2plsnf = 0
        self.hse65sze_total = 0
        self.hse65sze_w = 0
        self.hse65sze_w1 = 0
        self.hse65sze_w2pls = 0
        self.hse65sze_w2plsf = 0
        self.hse65sze_w2plsnf = 0
        self.hse65sze_n = 0
        self.hse65sze_n1 = 0
        self.hse65sze_n2pls = 0
        self.hse65sze_n2plsf = 0
        self.hse65sze_n2plsnf = 0
        self.hse75sze_total = 0
        self.hse75sze_w = 0
        self.hse75sze_w1 = 0
        self.hse75sze_w2pls = 0
        self.hse75sze_w2plsf = 0
        self.hse75sze_w2plsnf = 0
        self.hse75sze_n = 0
        self.hse75sze_n1 = 0
        self.hse75sze_n2pls = 0
        self.hse75sze_n2plsf = 0
        self.hse75sze_n2plsnf = 0
        self.nonrel_total = 0
        self.nonrel_1m = 0
        self.nonrel_no = 0
        self.hsesze_total = 0
        self.hsesze_f = 0
        self.hsesze_f2 = 0
        self.hsesze_f3 = 0
        self.hsesze_f4 = 0
        self.hsesze_f5 = 0
        self.hsesze_f6 = 0
        self.hsesze_f7pl = 0
        self.hsesze_n = 0
        self.hsesze_n1 = 0
        self.hsesze_n2 = 0
        self.hsesze_n3 = 0
        self.hsesze_n4 = 0
        self.hsesze_n5 = 0
        self.hsesze_n6 = 0
        self.hsesze_n7pl = 0
        self.hserel_total = 0
        self.hserel_h = 0
        self.hserel_f = 0
        self.hserel_fh = 0
        self.hserel_fmh = 0
        self.hserel_ffh = 0
        self.hserel_fs = 0
        self.hserel_fbc = 0
        self.hserel_fac = 0
        self.hserel_fsc = 0
        self.hserel_fgc = 0
        self.hserel_fbs = 0
        self.hserel_fp = 0
        self.hserel_fpl = 0
        self.hserel_fsdl = 0
        self.hserel_for = 0
        self.hserel_fnr = 0
        self.hserel_n = 0
        self.hserel_nmh = 0
        self.hserel_nmhla = 0
        self.hserel_nmhnla = 0
        self.hserel_nfh = 0
        self.hserel_nfhla = 0
        self.hserel_nfhnla = 0
        self.hserel_nnr = 0
        self.hserel_igq = 0
        self.hserel_ip = 0
        self.hserel_np = 0
        self.hsepop_total = 0
        self.hsepop_f = 0
        self.hsepop_fhw = 0
        self.hsepop_fof = 0
        self.hsepop_fmh = 0
        self.hsepop_ffh = 0
        self.hsepop_n = 0
        self.hsepop_nm = 0
        self.hsepop_nm1 = 0
        self.hsepop_nm2 = 0
        self.hsepop_nf = 0
        self.hsepop_nf1 = 0
        self.hsepop_nf2 = 0

        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.hsphse_total = d["hsphse_total"]
            self.hsphse_not = d["hsphse_not"]
            self.hsphse_notwhtal = d["hsphse_notwhtal"]
            self.hspse_notblkal = d["hspse_notblkal"]
            self.hsphse_notaianal = d["hsphse_notaianal"]
            self.hsphse_notasial = d["hsphse_notasial"]
            self.hsphse_notnhopial = d["hsphse_notnhopial"]
            self.hsphse_notothal = d["hsphse_notothal"]
            self.hsphse_nottwoplus = d["hsphse_nottwoplus"]
            self.hsphse_is = d["hsphse_is"]
            self.hsphse_whtal = d["hsphse_whtal"]
            self.hsphse_blkal = d["hsphse_blkal"]
            self.hsphse_aianal = d["hsphse_aianal"]
            self.hsphse_asial = d["hsphse_asial"]
            self.hsphse_nhopial = d["hsphse_nhopial"]
            self.hsphse_othal = d["hsphse_othal"]
            self.hsphse_twoplus = d["hsphse_twoplus"]
            self.popage_total = d["popage_total"]
            self.popage_und18 = d["popage_und18"]
            self.popage_18plus = d["popage_18plus"]
            self.avghse_total = d["avghse_total"]
            self.avghse_und18 = d["avghse_und18"]
            self.avghse_18plus = d["avghse_18plus"]
            self.hsetyp_total = d["hsetyp_total"]
            self.hsetyp_fam = d["hsetyp_fam"]
            self.hsetyp_hwf = d["hsetyp_hwf"]
            self.hsetyp_of = d["hsetyp_of"]
            self.hsetyp_mh = d["hsetyp_mh"]
            self.hsetyp_fh = d["hsetyp_fh"]
            self.hsetyp_nfh = d["hsetyp_nfh"]
            self.hsetyp_nfhal = d["hsetyp_nfhal"]
            self.hsetyp_nfhnotal = d["hsetyp_nfhnotal"]
            self.hseownchd_total = d["hseownchd_total"]
            self.hseownchd_1h = d["hseownchd_1h"]
            self.hseownchd_1mh = d["hseownchd_1mh"]
            self.hseownchd_1fh = d["hseownchd_1fh"]
            self.hseownchd_2ph = d["hseownchd_2ph"]
            self.hseownchd_famh = d["hseownchd_famh"]
            self.hseownchd_hwh = d["hseownchd_hwh"]
            self.hseownchd_hwchd = d["hseownchd_hwchd"]
            self.hseownchd_hwnochd = d["hseownchd_hwnochd"]
            self.hseownchd_of = d["hseownchd_of"]
            self.hseownchd_ofm = d["hseownchd_ofm"]
            self.hseownchd_ofmchd = d["hseownchd_ofmchd"]
            self.hseownchd_ofmnochd = d["hseownchd_ofmnochd"]
            self.hseownchd_off = d["hseownchd_off"]
            self.hseownchd_offchd = d["hseownchd_offchd"]
            self.hseownchd_offnochd = d["hseownchd_offnochd"]
            self.hseownchd_nf = d["hseownchd_nf"]
            self.hseownchd_nfmh = d["hseownchd_nfmh"]
            self.hseownchd_nffh = d["hseownchd_nffh"]
            self.hse18_total = d["hse18_total"]
            self.hse18_with = d["hse18_with"]
            self.hse18_fam = d["hse18_fam"]
            self.hse18_hwfam = d["hse18_hwfam"]
            self.hse18_hwund6 = d["hse18_hwund6"]
            self.hse18_hwund6to17 = d["hse18_hwund6to17"]
            self.hse18_hw6to17 = d["hse18_hw6to17"]
            self.hse18_ofam = d["hse18_ofam"]
            self.hse18_ofmh = d["hse18_ofmh"]
            self.hse18_omhund6 = d["hse18_omhund6"]
            self.hse18_omhund6to17 = d["hse18_omhund6to17"]
            self.hse18_omh6to17 = d["hse18_omh6to17"]
            self.hse18_offh = d["hse18_offh"]
            self.hse18_ofwund6 = d["hse18_ofwund6"]
            self.hse18_ofwund6to17 = d["hse18_ofwund6to17"]
            self.hse18_ofw6to17 = d["hse18_ofw6to17"]
            self.hse18_nfam = d["hse18_nfam"]
            self.hse18_nm = d["hse18_nm"]
            self.hse18_nmund6 = d["hse18_nmund6"]
            self.hse18_nmund6to17 = d["hse18_nmund6to17"]
            self.hse18_nm6to17 = d["hse18_nm6to17"]
            self.hse18_nf = d["hse18_nf"]
            self.hse18_nfund6 = d["hse18_nfund6"]
            self.hse18_nfund6to17 = d["hse18_nfund6to17"]
            self.hse18_nf6to17 = d["hse18_nf6to17"]
            self.hse18_not = d["hse18_not"]
            self.hse18_notfam = d["hse18_notfam"]
            self.hse18_nothwf = d["hse18_nothwf"]
            self.hse18_notof = d["hse18_notof"]
            self.hse18_notmh = d["hse18_notmh"]
            self.hse18_notfh = d["hse18_notfh"]
            self.hse18_notn = d["hse18_notn"]
            self.hse18_notnm = d["hse18_notnm"]
            self.hse18_notnf = d["hse18_notnf"]
            self.hsechd_total = d["hsechd_total"]
            self.hsechd_15to64 = d["hsechd_15to64"]
            self.hsechd_15to64f = d["hsechd_15to64f"]
            self.hsechd_15to64hwf = d["hsechd_15to64hwf"]
            self.hsechd_15to64hwfchd = d["hsechd_15to64hwfchd"]
            self.hsechd_15to64hwfno = d["hsechd_15to64hwfno"]
            self.hsechd_15to64of = d["hsechd_15to64of"]
            self.hsechd_15to64mh = d["hsechd_15to64mh"]
            self.hsechd_15to64mhchd = d["hsechd_15to64mhchd"]
            self.hsechd_15to64mhno = d["hsechd_15to64mhno"]
            self.hsechd_15to64fh = d["hsechd_15to64fh"]
            self.hsechd_15to64fhchd = d["hsechd_15to64fhchd"]
            self.hsechd_15to64fhno = d["hsechd_15to64fhno"]
            self.hsechd_15to64nf = d["hsechd_15to64nf"]
            self.hsechd_15to64nfal = d["hsechd_15to64nfal"]
            self.hsechd_15to64nfnal = d["hsechd_15to64nfnal"]
            self.hsechd_65pl = d["hsechd_65pl"]
            self.hsechd_65plf = d["hsechd_65plf"]
            self.hsechd_65plhwf = d["hsechd_65plhwf"]
            self.hsechd_65plhwfchd = d["hsechd_65plhwfchd"]
            self.hsechd_65plhwfno = d["hsechd_65plhwfno"]
            self.hsechd_65plof = d["hsechd_65plof"]
            self.hsechd_65plmh = d["hsechd_65plmh"]
            self.hsechd_65plmhchd = d["hsechd_65plmhchd"]
            self.hsechd_65plmhno = d["hsechd_65plmhno"]
            self.hsechd_65plfh = d["hsechd_65plfh"]
            self.hsechd_65plfhchd = d["hsechd_65plfhchd"]
            self.hsechd_65plfhno = d["hsechd_65plfhno"]
            self.hsechd_65plnf = d["hsechd_65plnf"]
            self.hsechd_65plnfal = d["hsechd_65plnfal"]
            self.hsechd_65plnfnal = d["hsechd_65plnfnal"]
            self.hsehld_total = d["hsehld_total"]
            self.hsehld_fam = d["hsehld_fam"]
            self.hsehld_fam15to24 = d["hsehld_fam15to24"]
            self.hsehld_fam25to34 = d["hsehld_fam25to34"]
            self.hsehld_fam35to44 = d["hsehld_fam35to44"]
            self.hsehld_fam45to54 = d["hsehld_fam45to54"]
            self.hsehld_fam55to59 = d["hsehld_fam55to59"]
            self.hsehld_fam60to64 = d["hsehld_fam60to64"]
            self.hsehld_fam65to74 = d["hsehld_fam65to74"]
            self.hsehld_fam75to84 = d["hsehld_fam75to84"]
            self.hsehld_fam85 = d["hsehld_fam85"]
            self.hsehld_nonfam = d["hsehld_nonfam"]
            self.hsehld_nonfam15to24 = d["hsehld_nonfam15to24"]
            self.hsehld_nonfam25to34 = d["hsehld_nonfam25to34"]
            self.hsehld_nonfam35to44 = d["hsehld_nonfam35to44"]
            self.hsehld_nonfam45to54 = d["hsehld_nonfam45to54"]
            self.hsehld_nonfam55to59 = d["hsehld_nonfam55to59"]
            self.hsehld_nonfam60to64 = d["hsehld_nonfam60to64"]
            self.hsehld_nonfam65to74 = d["hsehld_nonfam65to74"]
            self.hsehld_nonfam75to84 = d["hsehld_nonfam75to84"]
            self.hsehld_nonfam85 = d["hsehld_nonfam85"]
            self.hse60_total = d["hse60_total"]
            self.hse60_w = d["hse60_w"]
            self.hse60_wf = d["hse60_wf"]
            self.hse60_whw = d["hse60_whw"]
            self.hse60_wof = d["hse60_wof"]
            self.hse60_wofm = d["hse60_wofm"]
            self.hse60_woff = d["hse60_woff"]
            self.hse60_wnf = d["hse60_wnf"]
            self.hse60_n = d["hse60_n"]
            self.hse60_nf = d["hse60_nf"]
            self.hse60_nhw = d["hse60_nhw"]
            self.hse60_nof = d["hse60_nof"]
            self.hse60_nofm = d["hse60_nofm"]
            self.hse60_noff = d["hse60_noff"]
            self.hse60_nnf = d["hse60_nnf"]
            self.hse60sze_total = d["hse60sze_total"]
            self.hse60sze_w = d["hse60sze_w"]
            self.hse60sze_w1 = d["hse60sze_w1"]
            self.hse60sze_w2pls = d["hse60sze_w2pls"]
            self.hse60sze_w2plsf = d["hse60sze_w2plsf"]
            self.hse60sze_w2plsnf = d["hse60sze_w2plsnf"]
            self.hse60sze_n = d["hse60sze_n"]
            self.hse60sze_n1 = d["hse60sze_n1"]
            self.hse60sze_n2pls = d["hse60sze_n2pls"]
            self.hse60sze_n2plsf = d["hse60sze_n2plsf"]
            self.hse60sze_n2plsnf = d["hse60sze_n2plsnf"]
            self.hse65sze_total = d["hse65sze_total"]
            self.hse65sze_w = d["hse65sze_w"]
            self.hse65sze_w1 = d["hse65sze_w1"]
            self.hse65sze_w2pls = d["hse65sze_w2pls"]
            self.hse65sze_w2plsf = d["hse65sze_w2plsf"]
            self.hse65sze_w2plsnf = d["hse65sze_w2plsnf"]
            self.hse65sze_n = d["hse65sze_n"]
            self.hse65sze_n1 = d["hse65sze_n1"]
            self.hse65sze_n2pls = d["hse65sze_n2pls"]
            self.hse65sze_n2plsf = d["hse65sze_n2plsf"]
            self.hse65sze_n2plsnf = d["hse65sze_n2plsnf"]
            self.hse75sze_total = d["hse75sze_total"]
            self.hse75sze_w = d["hse75sze_w"]
            self.hse75sze_w1 = d["hse75sze_w1"]
            self.hse75sze_w2pls = d["hse75sze_w2pls"]
            self.hse75sze_w2plsf = d["hse75sze_w2plsf"]
            self.hse75sze_w2plsnf = d["hse75sze_w2plsnf"]
            self.hse75sze_n = d["hse75sze_n"]
            self.hse75sze_n1 = d["hse75sze_n1"]
            self.hse75sze_n2pls = d["hse75sze_n2pls"]
            self.hse75sze_n2plsf = d["hse75sze_n2plsf"]
            self.hse75sze_n2plsnf = d["hse75sze_n2plsnf"]
            self.nonrel_total = d["nonrel_total"]
            self.nonrel_1m = d["nonrel_1m"]
            self.nonrel_no = d["nonrel_no"]
            self.hsesze_total = d["hsesze_total"]
            self.hsesze_f = d["hsesze_f"]
            self.hsesze_f2 = d["hsesze_f2"]
            self.hsesze_f3 = d["hsesze_f3"]
            self.hsesze_f4 = d["hsesze_f4"]
            self.hsesze_f5 = d["hsesze_f5"]
            self.hsesze_f6 = d["hsesze_f6"]
            self.hsesze_f7pl = d["hsesze_f7pl"]
            self.hsesze_n = d["hsesze_n"]
            self.hsesze_n1 = d["hsesze_n1"]
            self.hsesze_n2 = d["hsesze_n2"]
            self.hsesze_n3 = d["hsesze_n3"]
            self.hsesze_n4 = d["hsesze_n4"]
            self.hsesze_n5 = d["hsesze_n5"]
            self.hsesze_n6 = d["hsesze_n6"]
            self.hsesze_n7pl = d["hsesze_n7pl"]
            self.hserel_total = d["hserel_total"]
            self.hserel_h = d["hserel_h"]
            self.hserel_f = d["hserel_f"]
            self.hserel_fh = d["hserel_fh"]
            self.hserel_fmh = d["hserel_fmh"]
            self.hserel_ffh = d["hserel_ffh"]
            self.hserel_fs = d["hserel_fs"]
            self.hserel_fbc = d["hserel_fbc"]
            self.hserel_fac = d["hserel_fac"]
            self.hserel_fsc = d["hserel_fsc"]
            self.hserel_fgc = d["hserel_fgc"]
            self.hserel_fbs = d["hserel_fbs"]
            self.hserel_fp = d["hserel_fp"]
            self.hserel_fpl = d["hserel_fpl"]
            self.hserel_fsdl = d["hserel_fsdl"]
            self.hserel_for = d["hserel_for"]
            self.hserel_fnr = d["hserel_fnr"]
            self.hserel_n = d["hserel_n"]
            self.hserel_nmh = d["hserel_nmh"]
            self.hserel_nmhla = d["hserel_nmhla"]
            self.hserel_nmhnla = d["hserel_nmhnla"]
            self.hserel_nfh = d["hserel_nfh"]
            self.hserel_nfhla = d["hserel_nfhla"]
            self.hserel_nfhnla = d["hserel_nfhnla"]
            self.hserel_nnr = d["hserel_nnr"]
            self.hserel_igq = d["hserel_igq"]
            self.hserel_ip = d["hserel_ip"]
            self.hserel_np = d["hserel_np"]
            self.hsepop_total = d["hsepop_total"]
            self.hsepop_f = d["hsepop_f"]
            self.hsepop_fhw = d["hsepop_fhw"]
            self.hsepop_fof = d["hsepop_fof"]
            self.hsepop_fmh = d["hsepop_fmh"]
            self.hsepop_ffh = d["hsepop_ffh"]
            self.hsepop_n = d["hsepop_n"]
            self.hsepop_nm = d["hsepop_nm"]
            self.hsepop_nm1 = d["hsepop_nm1"]
            self.hsepop_nm2 = d["hsepop_nm2"]
            self.hsepop_nf = d["hsepop_nf"]
            self.hsepop_nf1 = d["hsepop_nf1"]
            self.hsepop_nf2 = d["hsepop_nf2"]


class SF106():
    "Census SF1 File 06"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.p31_total = 0
        self.p31_in_households = 0
        self.p31_householder_or_spouse = 0
        self.p31_rel_child = 0
        self.p31_own_child = 0
        self.p31_hw_fam = 0
        self.p31_other_fam = 0
        self.p31_no_w_fam = 0
        self.p31_no_h_fam = 0
        self.p31_other_relatives = 0
        self.p31_grandchildren = 0
        self.p31_nongrandchildren = 0
        self.p31_nonrelatives = 0
        self.p31_in_group = 0
        self.p31_inst = 0
        self.p31_noninst = 0
        self.p32_total = 0
        self.p32_householder_or_spouse = 0
        self.p32_in_households = 0
        self.p32_rel_child = 0
        self.p32_own_child = 0
        self.p32_own_u3 = 0
        self.p32_own_3to4 = 0
        self.p32_own_5 = 0
        self.p32_own_6to11 = 0
        self.p32_own_12to13 = 0
        self.p32_own_14 = 0
        self.p32_own_15to17 = 0
        self.p32_other_relatives = 0
        self.p32_other_u3 = 0
        self.p32_other_3to4 = 0
        self.p32_other_5 = 0
        self.p32_other_6to11 = 0
        self.p32_other_12to13 = 0
        self.p32_other_14 = 0
        self.p32_other_15to17 = 0
        self.p32_nonrelatives = 0
        self.p32_non_u3 = 0
        self.p32_non_3to4 = 0
        self.p32_non_5 = 0
        self.p32_non_6to11 = 0
        self.p32_non_12to13 = 0
        self.p32_non_14 = 0
        self.p32_non_15to17 = 0
        self.p32_in_group = 0
        self.p32_inst_population = 0
        self.p32_inst_u3 = 0
        self.p32_inst_3to4 = 0
        self.p32_inst_5 = 0
        self.p32_inst_6to11 = 0
        self.p32_inst_12to13 = 0
        self.p32_inst_14 = 0
        self.p32_inst_15to17 = 0
        self.p32_noninst_population = 0
        self.p32_noninst_u3 = 0
        self.p32_noninst_3to4 = 0
        self.p32_noninst_5 = 0
        self.p32_noninst_6to11 = 0
        self.p32_noninst_12to13 = 0
        self.p32_noninst_14 = 0
        self.p32_noninst_15to17 = 0
        self.p33_total = 0
        self.p33_fam = 0
        self.p33_hw_fam = 0
        self.p33_other_fam = 0
        self.p33_no_w_fam = 0
        self.p33_no_h_fam = 0
        self.p33_no_fam = 0
        self.p34_total = 0
        self.p34_households = 0
        self.p34_fam_households = 0
        self.p34_fam_holder = 0
        self.p34_fam_m_holder = 0
        self.p34_fam_f_holder = 0
        self.p34_fam_spouse = 0
        self.p34_fam_parent = 0
        self.p34_fam_inlaw = 0
        self.p34_fam_other = 0
        self.p34_fam_nonrelatives = 0
        self.p34_nonfamily_households = 0
        self.p34_nonfamily_m_holder = 0
        self.p34_nonfamily_m_alone = 0
        self.p34_nonfamily_m_not_alone = 0
        self.p34_nonfamily_f_holder = 0
        self.p34_nonfamily_f_alone = 0
        self.p34_nonfamily_f_not_alone = 0
        self.p34_nonfamily_nonrelatives = 0
        self.p34_in_group = 0
        self.p34_inst = 0
        self.p34_noninst = 0
        self.p35_total = 0
        self.p36_total = 0
        self.p36_u18 = 0
        self.p36_18o = 0
        self.p37_total = decimal.Decimal(0)
        self.p37_u18 = decimal.Decimal(0)
        self.p38_no_w_fam = 0
        self.p37_18o = decimal.Decimal(0)
        self.p38_total = 0
        self.p38_hw_fam = 0
        self.p38_hw_fam_own_u18 = 0
        self.p38_hw_fam_own_u6 = 0
        self.p38_hw_fam_own_u6_and_6to17 = 0
        self.p38_hw_fam_own_6to17 = 0
        self.p38_hw_fam_own_none_u18 = 0
        self.p38_other_fam = 0
        self.p38_no_w_fam_own_u18 = 0
        self.p38_no_w_fam_own_u6 = 0
        self.p38_no_w_fam_own_u6_and_6to17 = 0
        self.p38_no_w_fam_own_6to17 = 0
        self.p38_no_w_fam_own_none_u18 = 0
        self.p38_no_h_fam = 0
        self.p38_no_h_fam_own_u18 = 0
        self.p38_no_h_fam_own_u6 = 0
        self.p38_no_h_fam_own_u6_and_6to17 = 0
        self.p38_no_h_fam_own_6to17 = 0
        self.p38_no_h_fam_own_none_u18 = 0
        self.p39_total = 0
        self.p39_hw_fam = 0
        self.p39_hw_fam_rel_u18 = 0
        self.p39_hw_fam_rel_u6 = 0
        self.p39_hw_fam_rel_u6_and_6to17 = 0
        self.p39_hw_fam_rel_6to17 = 0
        self.p39_hw_fam_rel_none_u18 = 0
        self.p39_other_fam = 0
        self.p39_no_h_fam_rel_6to17 = 0
        self.p39_no_w_fam = 0
        self.p39_no_h_fam_rel_none_u18 = 0
        self.p39_no_w_fam_rel_u18 = 0
        self.p39_no_w_fam_rel_u6 = 0
        self.p39_no_w_fam_rel_u6_and_6to17 = 0
        self.p39_no_w_fam_rel_6to17 = 0
        self.p39_no_w_fam_rel_none_u18 = 0
        self.p39_no_h_fam = 0
        self.p39_no_h_fam_rel_u18 = 0
        self.p39_no_h_fam_rel_u6 = 0
        self.p39_no_h_fam_rel_u6_and_6to17 = 0
        self.p40_total = 0
        self.p40_hw_fam = 0
        self.p40_hw_fam_u3 = 0
        self.p40_hw_fam_3to4 = 0
        self.p40_hw_fam_5 = 0
        self.p40_hw_fam_6toll = 0
        self.p40_hw_fam_12to17 = 0
        self.p40_other_fam = 0
        self.p40_no_w_fam = 0
        self.p40_no_w_fam_u3 = 0
        self.p40_no_w_fam_3to4 = 0
        self.p40_no_w_fam_5 = 0
        self.p40_no_w_fam_6to11 = 0
        self.p40_no_w_fam_12to17 = 0
        self.p40_no_h_fam = 0
        self.p40_no_h_fam_under3 = 0
        self.p40_no_h_fam_3to4 = 0
        self.p40_no_h_fam_5 = 0
        self.p40_no_h_fam_6to11 = 0
        self.p40_no_h_fam_12to17 = 0
        self.p41_total = 0
        self.p41_grandchildren_u3 = 0
        self.p41_grandchildren_3to4 = 0
        self.p41_grandchildren_5years = 0
        self.p41_grandchildren_6to11 = 0
        self.p41_grandchildren_12to17 = 0
        self.p42_total = 0
        self.p42_inst_population = 0
        self.p42_adult_cor_fac = 0
        self.p42_juvinile_fac = 0
        self.p42_nursing_fac = 0
        self.p42_other_inst_fac = 0
        self.p42_noninst_population = 0
        self.p42_student_housing = 0
        self.p42_military_quarters = 0
        self.p42_other_noninst_fac = 0
        self.p43_total = 0
        self.p43_m_group_quarters = 0
        self.p43_m_u18_group_quarters = 0
        self.p43_m_u18_inst_population = 0
        self.p43_m_u18_adult_cor_fac = 0
        self.p43_m_u18_juvinile_fac = 0
        self.p43_m_u18_nursing_fac = 0
        self.p43_m_u18_other_inst_fac = 0
        self.p43_m_u18_noninst_population = 0
        self.p43_m_u18_student_housing = 0
        self.p43_m_u18_military_quarters = 0
        self.p43_m_u18_other_noninst_fac = 0
        self.p43_m_18to64_group_quarters = 0
        self.p43_m_18to64_inst_population = 0
        self.p43_m_18to64_adult_cor_fac = 0
        self.p43_m_18to64_juvinile_fac = 0
        self.p43_m_18to64_nursing_fac = 0
        self.p43_m_18to64_other_inst_fac = 0
        self.p43_m_18to64_noninst_population = 0
        self.p43_m_18to64_student_housing = 0
        self.p43_m_18to64_military_quarters = 0
        self.p43_m_18to64_other_noninst_fac = 0
        self.p43_m_65o_group_quarters = 0
        self.p43_m_65over_in_inst_population = 0
        self.p43_m_65o_adult_cor_fac = 0
        self.p43_m_65o_juvinile_fac = 0
        self.p43_m_65o_nursing_fac = 0
        self.p43_m_65o_other_inst_fac = 0
        self.p43_m_65o_noninst_population = 0
        self.p43_m_65o_student_housing = 0
        self.p43_m_65o_military_quarters = 0
        self.p43_m_65o_other_noninst_fac = 0
        self.p43_f_group_quarters = 0
        self.p43_f_u18_group_quarters = 0
        self.p43_f_u18_inst_population = 0
        self.p43_f_u18_adult_cor_fac = 0
        self.p43_f_u18_juvinile_fac = 0
        self.p43_f_u18_nursing_fac = 0
        self.p43_f_u18_other_inst_fac = 0
        self.p43_f_u18_noninst_population = 0
        self.p43_f_u18_student_housing = 0
        self.p43_f_u18_military_quarters = 0
        self.p43_f_u18_other_noninst_fac = 0
        self.p43_f_18to64_group_quarters = 0
        self.p43_f_18to64_inst_population = 0
        self.p43_f_18to64_adult_cor_fac = 0
        self.p43_f_18to64_juvinile_fac = 0
        self.p43_f_18to64_nursing_fac = 0
        self.p43_f_18to64_other_inst_fac = 0
        self.p43_f_18to64_noninst_population = 0
        self.p43_f_18to64_student_housing = 0
        self.p43_f_18to64_military_quarters = 0
        self.p43_f_18to64_other_noninst_fac = 0
        self.p43_f_65o_group_quarters = 0
        self.p43_f_65o_inst_population = 0
        self.p43_f_65o_adult_cor_fac = 0
        self.p43_f_65o_juvinile_fac = 0
        self.p43_f_65o_nursing_fac = 0
        self.p43_f_65o_other_inst_fac = 0
        self.p43_f_65o_noninst_population = 0
        self.p43_f_65o_student_housing = 0
        self.p43_f_65o_military_quarters = 0
        self.p43_f_65o_other_noninst_fac = 0
        self.p44_total = 0
        self.p44_none_allocated = 0
        self.p44_allocated = 0
        self.p45_total = 0
        self.p45_none_allocated = 0
        self.p45_allocated = 0
        self.p46_total = 0
        self.p46_none_allocated = 0
        self.p46_allocated = 0
        self.p47_total = 0
        self.p47_none_allocated = 0
        self.p47_allocated = 0
        self.p48_total = 0
        self.p48_none_allocated = 0
        self.p48_allocated = 0
        self.p49_total = 0
        self.p49_none_allocated = 0
        self.p49_allocated = 0

        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.p31_total = d["p31_total"]
            self.p31_in_households = d["p31_in_households"]
            self.p31_householder_or_spouse = d["p31_householder_or_spouse"]
            self.p31_rel_child = d["p31_rel_child"]
            self.p31_own_child = d["p31_own_child"]
            self.p31_hw_fam = d["p31_hw_fam"]
            self.p31_other_fam = d["p31_other_fam"]
            self.p31_no_w_fam = d["p31_no_w_fam"]
            self.p31_no_h_fam = d["p31_no_h_fam"]
            self.p31_other_relatives = d["p31_other_relatives"]
            self.p31_grandchildren = d["p31_grandchildren"]
            self.p31_nongrandchildren = d["p31_nongrandchildren"]
            self.p31_nonrelatives = d["p31_nonrelatives"]
            self.p31_in_group = d["p31_in_group"]
            self.p31_inst = d["p31_inst"]
            self.p31_noninst = d["p31_noninst"]
            self.p32_total = d["p32_total"]
            self.p32_householder_or_spouse = d["p32_householder_or_spouse"]
            self.p32_in_households = d["p32_in_households"]
            self.p32_rel_child = d["p32_rel_child"]
            self.p32_own_child = d["p32_own_child"]
            self.p32_own_u3 = d["p32_own_u3"]
            self.p32_own_3to4 = d["p32_own_3to4"]
            self.p32_own_5 = d["p32_own_5"]
            self.p32_own_6to11 = d["p32_own_6to11"]
            self.p32_own_12to13 = d["p32_own_12to13"]
            self.p32_own_14 = d["p32_own_14"]
            self.p32_own_15to17 = d["p32_own_15to17"]
            self.p32_other_relatives = d["p32_other_relatives"]
            self.p32_other_u3 = d["p32_other_u3"]
            self.p32_other_3to4 = d["p32_other_3to4"]
            self.p32_other_5 = d["p32_other_5"]
            self.p32_other_6to11 = d["p32_other_6to11"]
            self.p32_other_12to13 = d["p32_other_12to13"]
            self.p32_other_14 = d["p32_other_14"]
            self.p32_other_15to17 = d["p32_other_15to17"]
            self.p32_nonrelatives = d["p32_nonrelatives"]
            self.p32_non_u3 = d["p32_non_u3"]
            self.p32_non_3to4 = d["p32_non_3to4"]
            self.p32_non_5 = d["p32_non_5"]
            self.p32_non_6to11 = d["p32_non_6to11"]
            self.p32_non_12to13 = d["p32_non_12to13"]
            self.p32_non_14 = d["p32_non_14"]
            self.p32_non_15to17 = d["p32_non_15to17"]
            self.p32_in_group = d["p32_in_group"]
            self.p32_inst_population = d["p32_inst_population"]
            self.p32_inst_u3 = d["p32_inst_u3"]
            self.p32_inst_3to4 = d["p32_inst_3to4"]
            self.p32_inst_5 = d["p32_inst_5"]
            self.p32_inst_6to11 = d["p32_inst_6to11"]
            self.p32_inst_12to13 = d["p32_inst_12to13"]
            self.p32_inst_14 = d["p32_inst_14"]
            self.p32_inst_15to17 = d["p32_inst_15to17"]
            self.p32_noninst_population = d["p32_noninst_population"]
            self.p32_noninst_u3 = d["p32_noninst_u3"]
            self.p32_noninst_3to4 = d["p32_noninst_3to4"]
            self.p32_noninst_5 = d["p32_noninst_5"]
            self.p32_noninst_6to11 = d["p32_noninst_6to11"]
            self.p32_noninst_12to13 = d["p32_noninst_12to13"]
            self.p32_noninst_14 = d["p32_noninst_14"]
            self.p32_noninst_15to17 = d["p32_noninst_15to17"]
            self.p33_total = d["p33_total"]
            self.p33_fam = d["p33_fam"]
            self.p33_hw_fam = d["p33_hw_fam"]
            self.p33_other_fam = d["p33_other_fam"]
            self.p33_no_w_fam = d["p33_no_w_fam"]
            self.p33_no_h_fam = d["p33_no_h_fam"]
            self.p33_no_fam = d["p33_no_fam"]
            self.p34_total = d["p34_total"]
            self.p34_households = d["p34_households"]
            self.p34_fam_households = d["p34_fam_households"]
            self.p34_fam_holder = d["p34_fam_holder"]
            self.p34_fam_m_holder = d["p34_fam_m_holder"]
            self.p34_fam_f_holder = d["p34_fam_f_holder"]
            self.p34_fam_spouse = d["p34_fam_spouse"]
            self.p34_fam_parent = d["p34_fam_parent"]
            self.p34_fam_inlaw = d["p34_fam_inlaw"]
            self.p34_fam_other = d["p34_fam_other"]
            self.p34_fam_nonrelatives = d["p34_fam_nonrelatives"]
            self.p34_nonfamily_households = d["p34_nonfamily_households"]
            self.p34_nonfamily_m_holder = d["p34_nonfamily_m_holder"]
            self.p34_nonfamily_m_alone = d["p34_nonfamily_m_alone"]
            self.p34_nonfamily_m_not_alone = d["p34_nonfamily_m_not_alone"]
            self.p34_nonfamily_f_holder = d["p34_nonfamily_f_holder"]
            self.p34_nonfamily_f_alone = d["p34_nonfamily_f_alone"]
            self.p34_nonfamily_f_not_alone = d["p34_nonfamily_f_not_alone"]
            self.p34_nonfamily_nonrelatives = d["p34_nonfamily_nonrelatives"]
            self.p34_in_group = d["p34_in_group"]
            self.p34_inst = d["p34_inst"]
            self.p34_noninst = d["p34_noninst"]
            self.p35_total = d["p35_total"]
            self.p36_total = d["p36_total"]
            self.p36_u18 = d["p36_u18"]
            self.p36_18o = d["p36_18o"]
            self.p37_total = d["p37_total"]
            self.p37_u18 = d["p37_u18"]
            self.p38_no_w_fam = d["p38_no_w_fam"]
            self.p37_18o = d["p37_18o"]
            self.p38_total = d["p38_total"]
            self.p38_hw_fam = d["p38_hw_fam"]
            self.p38_hw_fam_own_u18 = d["p38_hw_fam_own_u18"]
            self.p38_hw_fam_own_u6 = d["p38_hw_fam_own_u6"]
            self.p38_hw_fam_own_u6_and_6to17 = d["p38_hw_fam_own_u6_and_6to17"]
            self.p38_hw_fam_own_6to17 = d["p38_hw_fam_own_6to17"]
            self.p38_hw_fam_own_none_u18 = d["p38_hw_fam_own_none_u18"]
            self.p38_other_fam = d["p38_other_fam"]
            self.p38_no_w_fam_own_u18 = d["p38_no_w_fam_own_u18"]
            self.p38_no_w_fam_own_u6 = d["p38_no_w_fam_own_u6"]
            self.p38_no_w_fam_own_u6_and_6to17 = d["p38_no_w_fam_own_u6_and_6to17"]
            self.p38_no_w_fam_own_6to17 = d["p38_no_w_fam_own_6to17"]
            self.p38_no_w_fam_own_none_u18 = d["p38_no_w_fam_own_none_u18"]
            self.p38_no_h_fam = d["p38_no_h_fam"]
            self.p38_no_h_fam_own_u18 = d["p38_no_h_fam_own_u18"]
            self.p38_no_h_fam_own_u6 = d["p38_no_h_fam_own_u6"]
            self.p38_no_h_fam_own_u6_and_6to17 = d["p38_no_h_fam_own_u6_and_6to17"]
            self.p38_no_h_fam_own_6to17 = d["p38_no_h_fam_own_6to17"]
            self.p38_no_h_fam_own_none_u18 = d["p38_no_h_fam_own_none_u18"]
            self.p39_total = d["p39_total"]
            self.p39_hw_fam = d["p39_hw_fam"]
            self.p39_hw_fam_rel_u18 = d["p39_hw_fam_rel_u18"]
            self.p39_hw_fam_rel_u6 = d["p39_hw_fam_rel_u6"]
            self.p39_hw_fam_rel_u6_and_6to17 = d["p39_hw_fam_rel_u6_and_6to17"]
            self.p39_hw_fam_rel_6to17 = d["p39_hw_fam_rel_6to17"]
            self.p39_hw_fam_rel_none_u18 = d["p39_hw_fam_rel_none_u18"]
            self.p39_other_fam = d["p39_other_fam"]
            self.p39_no_h_fam_rel_6to17 = d["p39_no_h_fam_rel_6to17"]
            self.p39_no_w_fam = d["p39_no_w_fam"]
            self.p39_no_h_fam_rel_none_u18 = d["p39_no_h_fam_rel_none_u18"]
            self.p39_no_w_fam_rel_u18 = d["p39_no_w_fam_rel_u18"]
            self.p39_no_w_fam_rel_u6 = d["p39_no_w_fam_rel_u6"]
            self.p39_no_w_fam_rel_u6_and_6to17 = d["p39_no_w_fam_rel_u6_and_6to17"]
            self.p39_no_w_fam_rel_6to17 = d["p39_no_w_fam_rel_6to17"]
            self.p39_no_w_fam_rel_none_u18 = d["p39_no_w_fam_rel_none_u18"]
            self.p39_no_h_fam = d["p39_no_h_fam"]
            self.p39_no_h_fam_rel_u18 = d["p39_no_h_fam_rel_u18"]
            self.p39_no_h_fam_rel_u6 = d["p39_no_h_fam_rel_u6"]
            self.p39_no_h_fam_rel_u6_and_6to17 = d["p39_no_h_fam_rel_u6_and_6to17"]
            self.p40_total = d["p40_total"]
            self.p40_hw_fam = d["p40_hw_fam"]
            self.p40_hw_fam_u3 = d["p40_hw_fam_u3"]
            self.p40_hw_fam_3to4 = d["p40_hw_fam_3to4"]
            self.p40_hw_fam_5 = d["p40_hw_fam_5"]
            self.p40_hw_fam_6toll = d["p40_hw_fam_6toll"]
            self.p40_hw_fam_12to17 = d["p40_hw_fam_12to17"]
            self.p40_other_fam = d["p40_other_fam"]
            self.p40_no_w_fam = d["p40_no_w_fam"]
            self.p40_no_w_fam_u3 = d["p40_no_w_fam_u3"]
            self.p40_no_w_fam_3to4 = d["p40_no_w_fam_3to4"]
            self.p40_no_w_fam_5 = d["p40_no_w_fam_5"]
            self.p40_no_w_fam_6to11 = d["p40_no_w_fam_6to11"]
            self.p40_no_w_fam_12to17 = d["p40_no_w_fam_12to17"]
            self.p40_no_h_fam = d["p40_no_h_fam"]
            self.p40_no_h_fam_under3 = d["p40_no_h_fam_under3"]
            self.p40_no_h_fam_3to4 = d["p40_no_h_fam_3to4"]
            self.p40_no_h_fam_5 = d["p40_no_h_fam_5"]
            self.p40_no_h_fam_6to11 = d["p40_no_h_fam_6to11"]
            self.p40_no_h_fam_12to17 = d["p40_no_h_fam_12to17"]
            self.p41_total = d["p41_total"]
            self.p41_grandchildren_u3 = d["p41_grandchildren_u3"]
            self.p41_grandchildren_3to4 = d["p41_grandchildren_3to4"]
            self.p41_grandchildren_5years = d["p41_grandchildren_5years"]
            self.p41_grandchildren_6to11 = d["p41_grandchildren_6to11"]
            self.p41_grandchildren_12to17 = d["p41_grandchildren_12to17"]
            self.p42_total = d["p42_total"]
            self.p42_inst_population = d["p42_inst_population"]
            self.p42_adult_cor_fac = d["p42_adult_cor_fac"]
            self.p42_juvinile_fac = d["p42_juvinile_fac"]
            self.p42_nursing_fac = d["p42_nursing_fac"]
            self.p42_other_inst_fac = d["p42_other_inst_fac"]
            self.p42_noninst_population = d["p42_noninst_population"]
            self.p42_student_housing = d["p42_student_housing"]
            self.p42_military_quarters = d["p42_military_quarters"]
            self.p42_other_noninst_fac = d["p42_other_noninst_fac"]
            self.p43_total = d["p43_total"]
            self.p43_m_group_quarters = d["p43_m_group_quarters"]
            self.p43_m_u18_group_quarters = d["p43_m_u18_group_quarters"]
            self.p43_m_u18_inst_population = d["p43_m_u18_inst_population"]
            self.p43_m_u18_adult_cor_fac = d["p43_m_u18_adult_cor_fac"]
            self.p43_m_u18_juvinile_fac = d["p43_m_u18_juvinile_fac"]
            self.p43_m_u18_nursing_fac = d["p43_m_u18_nursing_fac"]
            self.p43_m_u18_other_inst_fac = d["p43_m_u18_other_inst_fac"]
            self.p43_m_u18_noninst_population = d["p43_m_u18_noninst_population"]
            self.p43_m_u18_student_housing = d["p43_m_u18_student_housing"]
            self.p43_m_u18_military_quarters = d["p43_m_u18_military_quarters"]
            self.p43_m_u18_other_noninst_fac = d["p43_m_u18_other_noninst_fac"]
            self.p43_m_18to64_group_quarters = d["p43_m_18to64_group_quarters"]
            self.p43_m_18to64_inst_population = d["p43_m_18to64_inst_population"]
            self.p43_m_18to64_adult_cor_fac = d["p43_m_18to64_adult_cor_fac"]
            self.p43_m_18to64_juvinile_fac = d["p43_m_18to64_juvinile_fac"]
            self.p43_m_18to64_nursing_fac = d["p43_m_18to64_nursing_fac"]
            self.p43_m_18to64_other_inst_fac = d["p43_m_18to64_other_inst_fac"]
            self.p43_m_18to64_noninst_population = d["p43_m_18to64_noninst_population"]
            self.p43_m_18to64_student_housing = d["p43_m_18to64_student_housing"]
            self.p43_m_18to64_military_quarters = d["p43_m_18to64_military_quarters"]
            self.p43_m_18to64_other_noninst_fac = d["p43_m_18to64_other_noninst_fac"]
            self.p43_m_65o_group_quarters = d["p43_m_65o_group_quarters"]
            self.p43_m_65over_in_inst_population = d["p43_m_65over_in_inst_population"]
            self.p43_m_65o_adult_cor_fac = d["p43_m_65o_adult_cor_fac"]
            self.p43_m_65o_juvinile_fac = d["p43_m_65o_juvinile_fac"]
            self.p43_m_65o_nursing_fac = d["p43_m_65o_nursing_fac"]
            self.p43_m_65o_other_inst_fac = d["p43_m_65o_other_inst_fac"]
            self.p43_m_65o_noninst_population = d["p43_m_65o_noninst_population"]
            self.p43_m_65o_student_housing = d["p43_m_65o_student_housing"]
            self.p43_m_65o_military_quarters = d["p43_m_65o_military_quarters"]
            self.p43_m_65o_other_noninst_fac = d["p43_m_65o_other_noninst_fac"]
            self.p43_f_group_quarters = d["p43_f_group_quarters"]
            self.p43_f_u18_group_quarters = d["p43_f_u18_group_quarters"]
            self.p43_f_u18_inst_population = d["p43_f_u18_inst_population"]
            self.p43_f_u18_adult_cor_fac = d["p43_f_u18_adult_cor_fac"]
            self.p43_f_u18_juvinile_fac = d["p43_f_u18_juvinile_fac"]
            self.p43_f_u18_nursing_fac = d["p43_f_u18_nursing_fac"]
            self.p43_f_u18_other_inst_fac = d["p43_f_u18_other_inst_fac"]
            self.p43_f_u18_noninst_population = d["p43_f_u18_noninst_population"]
            self.p43_f_u18_student_housing = d["p43_f_u18_student_housing"]
            self.p43_f_u18_military_quarters = d["p43_f_u18_military_quarters"]
            self.p43_f_u18_other_noninst_fac = d["p43_f_u18_other_noninst_fac"]
            self.p43_f_18to64_group_quarters = d["p43_f_18to64_group_quarters"]
            self.p43_f_18to64_inst_population = d["p43_f_18to64_inst_population"]
            self.p43_f_18to64_adult_cor_fac = d["p43_f_18to64_adult_cor_fac"]
            self.p43_f_18to64_juvinile_fac = d["p43_f_18to64_juvinile_fac"]
            self.p43_f_18to64_nursing_fac = d["p43_f_18to64_nursing_fac"]
            self.p43_f_18to64_other_inst_fac = d["p43_f_18to64_other_inst_fac"]
            self.p43_f_18to64_noninst_population = d["p43_f_18to64_noninst_population"]
            self.p43_f_18to64_student_housing = d["p43_f_18to64_student_housing"]
            self.p43_f_18to64_military_quarters = d["p43_f_18to64_military_quarters"]
            self.p43_f_18to64_other_noninst_fac = d["p43_f_18to64_other_noninst_fac"]
            self.p43_f_65o_group_quarters = d["p43_f_65o_group_quarters"]
            self.p43_f_65o_inst_population = d["p43_f_65o_inst_population"]
            self.p43_f_65o_adult_cor_fac = d["p43_f_65o_adult_cor_fac"]
            self.p43_f_65o_juvinile_fac = d["p43_f_65o_juvinile_fac"]
            self.p43_f_65o_nursing_fac = d["p43_f_65o_nursing_fac"]
            self.p43_f_65o_other_inst_fac = d["p43_f_65o_other_inst_fac"]
            self.p43_f_65o_noninst_population = d["p43_f_65o_noninst_population"]
            self.p43_f_65o_student_housing = d["p43_f_65o_student_housing"]
            self.p43_f_65o_military_quarters = d["p43_f_65o_military_quarters"]
            self.p43_f_65o_other_noninst_fac = d["p43_f_65o_other_noninst_fac"]
            self.p44_total = d["p44_total"]
            self.p44_none_allocated = d["p44_none_allocated"]
            self.p44_allocated = d["p44_allocated"]
            self.p45_total = d["p45_total"]
            self.p45_none_allocated = d["p45_none_allocated"]
            self.p45_allocated = d["p45_allocated"]
            self.p46_total = d["p46_total"]
            self.p46_none_allocated = d["p46_none_allocated"]
            self.p46_allocated = d["p46_allocated"]
            self.p47_total = d["p47_total"]
            self.p47_none_allocated = d["p47_none_allocated"]
            self.p47_allocated = d["p47_allocated"]
            self.p48_total = d["p48_total"]
            self.p48_none_allocated = d["p48_none_allocated"]
            self.p48_allocated = d["p48_allocated"]
            self.p49_total = d["p49_total"]
            self.p49_none_allocated = d["p49_none_allocated"]
            self.p49_allocated = d["p49_allocated"]


class SF107():
    "Census SF1 File 07"
    def __init__(self, d=None):
        self.fileid = ""
        self.stusab = ""
        self.chariter = ""
        self.cifsn = ""
        self.logrecno = 0
        self.relationship_total = 0
        self.relationship_allocated = 0
        self.relationship_not_allocated = 0
        self.alloc_pop_group_qters_total = 0
        self.alloc_pop_group_qters_not = 0
        self.alloc_pop_group_qters_1m = 0
        self.sex_age_white_total = 0
        self.sex_age_white_m = 0
        self.sex_age_white_m_u5 = 0
        self.sex_age_white_m_5_9 = 0
        self.sex_age_white_m_10_14 = 0
        self.sex_age_white_m_15_17 = 0
        self.sex_age_white_m_18_19 = 0
        self.sex_age_white_m_20 = 0
        self.sex_age_white_m_21 = 0
        self.sex_age_white_m_22_24 = 0
        self.sex_age_white_m_25_29 = 0
        self.sex_age_white_m_30_34 = 0
        self.sex_age_white_m_35_39 = 0
        self.sex_age_white_m_40_44 = 0
        self.sex_age_white_m_45_49 = 0
        self.sex_age_white_m_50_54 = 0
        self.sex_age_white_m_55_59 = 0
        self.sex_age_white_m_60_61 = 0
        self.sex_age_white_m_62_64 = 0
        self.sex_age_white_m_65_66 = 0
        self.sex_age_white_m_67_69 = 0
        self.sex_age_white_m_70_74 = 0
        self.sex_age_white_m_75_79 = 0
        self.sex_age_white_m_80_84 = 0
        self.sex_age_white_m_85p = 0
        self.sex_age_white_f = 0
        self.sex_age_white_f_u5 = 0
        self.sex_age_white_f_5_9 = 0
        self.sex_age_white_f_10_14 = 0
        self.sex_age_white_f_15_17 = 0
        self.sex_age_white_f_18_19 = 0
        self.sex_age_white_f_20 = 0
        self.sex_age_white_f_21 = 0
        self.sex_age_white_f_22_24 = 0
        self.sex_age_white_f_25_29 = 0
        self.sex_age_white_f_30_34 = 0
        self.sex_age_white_f_35_39 = 0
        self.sex_age_white_f_40_44 = 0
        self.sex_age_white_f_45_49 = 0
        self.sex_age_white_f_50_54 = 0
        self.sex_age_white_f_55_59 = 0
        self.sex_age_white_f_60_61 = 0
        self.sex_age_white_f_62_64 = 0
        self.sex_age_white_f_65_66 = 0
        self.sex_age_white_f_67_69 = 0
        self.sex_age_white_f_70_74 = 0
        self.sex_age_white_f_75_79 = 0
        self.sex_age_white_f_80_84 = 0
        self.sex_age_white_f_85p = 0
        self.sex_age_black_total = 0
        self.sex_age_black_m = 0
        self.sex_age_black_m_u5 = 0
        self.sex_age_black_m_5_9 = 0
        self.sex_age_black_m_10_14 = 0
        self.sex_age_black_m_15_17 = 0
        self.sex_age_black_m_18_19 = 0
        self.sex_age_black_m_20 = 0
        self.sex_age_black_m_21 = 0
        self.sex_age_black_m_22_24 = 0
        self.sex_age_black_m_25_29 = 0
        self.sex_age_black_m_30_34 = 0
        self.sex_age_black_m_35_39 = 0
        self.sex_age_black_m_40_44 = 0
        self.sex_age_black_m_45_49 = 0
        self.sex_age_black_m_50_54 = 0
        self.sex_age_black_m_55_59 = 0
        self.sex_age_black_m_60_61 = 0
        self.sex_age_black_m_62_64 = 0
        self.sex_age_black_m_65_66 = 0
        self.sex_age_black_m_67_69 = 0
        self.sex_age_black_m_70_74 = 0
        self.sex_age_black_m_75_79 = 0
        self.sex_age_black_m_80_84 = 0
        self.sex_age_black_m_85p = 0
        self.sex_age_black_f = 0
        self.sex_age_black_f_u5 = 0
        self.sex_age_black_f_5_9 = 0
        self.sex_age_black_f_10_14 = 0
        self.sex_age_black_f_15_17 = 0
        self.sex_age_black_f_18_19 = 0
        self.sex_age_black_f_20 = 0
        self.sex_age_black_f_21 = 0
        self.sex_age_black_f_22_24 = 0
        self.sex_age_black_f_25_29 = 0
        self.sex_age_black_f_30_34 = 0
        self.sex_age_black_f_35_39 = 0
        self.sex_age_black_f_40_44 = 0
        self.sex_age_black_f_45_49 = 0
        self.sex_age_black_f_50_54 = 0
        self.sex_age_black_f_55_59 = 0
        self.sex_age_black_f_60_61 = 0
        self.sex_age_black_f_62_64 = 0
        self.sex_age_black_f_65_66 = 0
        self.sex_age_black_f_67_69 = 0
        self.sex_age_black_f_70_74 = 0
        self.sex_age_black_f_75_79 = 0
        self.sex_age_black_f_80_84 = 0
        self.sex_age_black_f_85p = 0
        self.sex_age_natam_total = 0
        self.sex_age_natam_m = 0
        self.sex_age_natam_m_u5 = 0
        self.sex_age_natam_m_5_9 = 0
        self.sex_age_natam_m_10_14 = 0
        self.sex_age_natam_m_15_17 = 0
        self.sex_age_natam_m_18_19 = 0
        self.sex_age_natam_m_20 = 0
        self.sex_age_natam_m_21 = 0
        self.sex_age_natam_m_22_24 = 0
        self.sex_age_natam_m_25_29 = 0
        self.sex_age_natam_m_30_34 = 0
        self.sex_age_natam_m_35_39 = 0
        self.sex_age_natam_m_40_44 = 0
        self.sex_age_natam_m_45_49 = 0
        self.sex_age_natam_m_50_54 = 0
        self.sex_age_natam_m_55_59 = 0
        self.sex_age_natam_m_60_61 = 0
        self.sex_age_natam_m_62_64 = 0
        self.sex_age_natam_m_65_66 = 0
        self.sex_age_natam_m_67_69 = 0
        self.sex_age_natam_m_70_74 = 0
        self.sex_age_natam_m_75_79 = 0
        self.sex_age_natam_m_80_84 = 0
        self.sex_age_natam_m_85p = 0
        self.sex_age_natam_f = 0
        self.sex_age_natam_f_u5 = 0
        self.sex_age_natam_f_5_9 = 0
        self.sex_age_natam_f_10_14 = 0
        self.sex_age_natam_f_15_17 = 0
        self.sex_age_natam_f_18_19 = 0
        self.sex_age_natam_f_20 = 0
        self.sex_age_natam_f_21 = 0
        self.sex_age_natam_f_22_24 = 0
        self.sex_age_natam_f_25_29 = 0
        self.sex_age_natam_f_30_34 = 0
        self.sex_age_natam_f_35_39 = 0
        self.sex_age_natam_f_40_44 = 0
        self.sex_age_natam_f_45_49 = 0
        self.sex_age_natam_f_50_54 = 0
        self.sex_age_natam_f_55_59 = 0
        self.sex_age_natam_f_60_61 = 0
        self.sex_age_natam_f_62_64 = 0
        self.sex_age_natam_f_65_66 = 0
        self.sex_age_natam_f_67_69 = 0
        self.sex_age_natam_f_70_74 = 0
        self.sex_age_natam_f_75_79 = 0
        self.sex_age_natam_f_80_84 = 0
        self.sex_age_natam_f_85p = 0
        self.sex_age_asian_total = 0
        self.sex_age_asian_m = 0
        self.sex_age_asian_m_u5 = 0
        self.sex_age_asian_m_5_9 = 0
        self.sex_age_asian_m_10_14 = 0
        self.sex_age_asian_m_15_17 = 0
        self.sex_age_asian_m_18_19 = 0
        self.sex_age_asian_m_20 = 0
        self.sex_age_asian_m_21 = 0
        self.sex_age_asian_m_22_24 = 0
        self.sex_age_asian_m_25_29 = 0
        self.sex_age_asian_m_30_34 = 0
        self.sex_age_asian_m_35_39 = 0
        self.sex_age_asian_m_40_44 = 0
        self.sex_age_asian_m_45_49 = 0
        self.sex_age_asian_m_50_54 = 0
        self.sex_age_asian_m_55_59 = 0
        self.sex_age_asian_m_60_61 = 0
        self.sex_age_asian_m_62_64 = 0
        self.sex_age_asian_m_65_66 = 0
        self.sex_age_asian_m_67_69 = 0
        self.sex_age_asian_m_70_74 = 0
        self.sex_age_asian_m_75_79 = 0
        self.sex_age_asian_m_80_84 = 0
        self.sex_age_asian_m_85p = 0
        self.sex_age_asian_f = 0
        self.sex_age_asian_f_u5 = 0
        self.sex_age_asian_f_5_9 = 0
        self.sex_age_asian_f_10_14 = 0
        self.sex_age_asian_f_15_17 = 0
        self.sex_age_asian_f_18_19 = 0
        self.sex_age_asian_f_20 = 0
        self.sex_age_asian_f_21 = 0
        self.sex_age_asian_f_22_24 = 0
        self.sex_age_asian_f_25_29 = 0
        self.sex_age_asian_f_30_34 = 0
        self.sex_age_asian_f_35_39 = 0
        self.sex_age_asian_f_40_44 = 0
        self.sex_age_asian_f_45_49 = 0
        self.sex_age_asian_f_50_54 = 0
        self.sex_age_asian_f_55_59 = 0
        self.sex_age_asian_f_60_61 = 0
        self.sex_age_asian_f_62_64 = 0
        self.sex_age_asian_f_65_66 = 0
        self.sex_age_asian_f_67_69 = 0
        self.sex_age_asian_f_70_74 = 0
        self.sex_age_asian_f_75_79 = 0
        self.sex_age_asian_f_80_84 = 0
        self.sex_age_asian_f_85p = 0
        self.sex_age_isl_total = 0
        self.sex_age_isl_m = 0
        self.sex_age_isl_m_u5 = 0
        self.sex_age_hawaii_isl_m_5_9 = 0
        self.sex_age_hawaii_isl_m_10_14 = 0
        self.sex_age_hawaii_isl_m_15_17 = 0
        self.sex_age_hawaii_isl_m_18_19 = 0
        self.sex_age_hawaii_isl_m_20 = 0
        self.sex_age_hawaii_isl_m_21 = 0
        self.sex_age_hawaii_isl_m_22_24 = 0
        self.sex_age_hawaii_isl_m_25_29 = 0
        self.sex_age_hawaii_isl_m_30_34 = 0
        self.sex_age_hawaii_isl_m_35_39 = 0
        self.sex_age_hawaii_isl_m_40_44 = 0
        self.sex_age_hawaii_isl_m_45_49 = 0
        self.sex_age_hawaii_isl_m_50_54 = 0
        self.sex_age_hawaii_isl_m_55_59 = 0
        self.sex_age_hawaii_isl_m_60_61 = 0
        self.sex_age_hawaii_isl_m_62_64 = 0
        self.sex_age_hawaii_isl_m_65_66 = 0
        self.sex_age_hawaii_isl_m_67_69 = 0
        self.sex_age_hawaii_isl_m_70_74 = 0
        self.sex_age_hawaii_isl_m_75_79 = 0
        self.sex_age_hawaii_isl_m_80_84 = 0
        self.sex_age_hawaii_isl_m_85p = 0
        self.sex_age_hawaii_isl_f = 0
        self.sex_age_hawaii_isl_f_u5 = 0
        self.sex_age_hawaii_isl_f_5_9 = 0
        self.sex_age_hawaii_isl_f_10_14 = 0
        self.sex_age_hawaii_isl_f_15_17 = 0
        self.sex_age_hawaii_isl_f_18_19 = 0
        self.sex_age_hawaii_isl_f_20 = 0
        self.sex_age_hawaii_isl_f_21 = 0
        self.sex_age_hawaii_isl_f_22_24 = 0
        self.sex_age_hawaii_isl_f_25_29 = 0
        self.sex_age_hawaii_isl_f_30_34 = 0
        self.sex_age_hawaii_isl_f_35_39 = 0
        self.sex_age_hawaii_isl_f_40_44 = 0
        self.sex_age_hawaii_isl_f_45_49 = 0
        self.sex_age_hawaii_isl_f_50_54 = 0
        self.sex_age_hawaii_isl_f_55_59 = 0
        self.sex_age_hawaii_isl_f_60_61 = 0
        self.sex_age_hawaii_isl_f_62_64 = 0
        self.sex_age_hawaii_isl_f_65_66 = 0
        self.sex_age_hawaii_isl_f_67_69 = 0
        self.sex_age_hawaii_isl_f_70_74 = 0
        self.sex_age_hawaii_isl_f_75_79 = 0
        self.sex_age_hawaii_isl_f_80_84 = 0
        self.sex_age_hawaii_isl_f_85p = 0

        if d is not None:
            self.fileid = d["fileid"]
            self.stusab = d["stusab"]
            self.chariter = d["chariter"]
            self.cifsn = d["cifsn"]
            self.logrecno = d["logrecno"]
            self.relationship_total = d["relationship_total"]
            self.relationship_allocated = d["relationship_allocated"]
            self.relationship_not_allocated = d["relationship_not_allocated"]
            self.alloc_pop_group_qters_total = d["alloc_pop_group_qters_total"]
            self.alloc_pop_group_qters_not = d["alloc_pop_group_qters_not"]
            self.alloc_pop_group_qters_1m = d["alloc_pop_group_qters_1m"]
            self.sex_age_white_total = d["sex_age_white_total"]
            self.sex_age_white_m = d["sex_age_white_m"]
            self.sex_age_white_m_u5 = d["sex_age_white_m_u5"]
            self.sex_age_white_m_5_9 = d["sex_age_white_m_5_9"]
            self.sex_age_white_m_10_14 = d["sex_age_white_m_10_14"]
            self.sex_age_white_m_15_17 = d["sex_age_white_m_15_17"]
            self.sex_age_white_m_18_19 = d["sex_age_white_m_18_19"]
            self.sex_age_white_m_20 = d["sex_age_white_m_20"]
            self.sex_age_white_m_21 = d["sex_age_white_m_21"]
            self.sex_age_white_m_22_24 = d["sex_age_white_m_22_24"]
            self.sex_age_white_m_25_29 = d["sex_age_white_m_25_29"]
            self.sex_age_white_m_30_34 = d["sex_age_white_m_30_34"]
            self.sex_age_white_m_35_39 = d["sex_age_white_m_35_39"]
            self.sex_age_white_m_40_44 = d["sex_age_white_m_40_44"]
            self.sex_age_white_m_45_49 = d["sex_age_white_m_45_49"]
            self.sex_age_white_m_50_54 = d["sex_age_white_m_50_54"]
            self.sex_age_white_m_55_59 = d["sex_age_white_m_55_59"]
            self.sex_age_white_m_60_61 = d["sex_age_white_m_60_61"]
            self.sex_age_white_m_62_64 = d["sex_age_white_m_62_64"]
            self.sex_age_white_m_65_66 = d["sex_age_white_m_65_66"]
            self.sex_age_white_m_67_69 = d["sex_age_white_m_67_69"]
            self.sex_age_white_m_70_74 = d["sex_age_white_m_70_74"]
            self.sex_age_white_m_75_79 = d["sex_age_white_m_75_79"]
            self.sex_age_white_m_80_84 = d["sex_age_white_m_80_84"]
            self.sex_age_white_m_85p = d["sex_age_white_m_85p"]
            self.sex_age_white_f = d["sex_age_white_f"]
            self.sex_age_white_f_u5 = d["sex_age_white_f_u5"]
            self.sex_age_white_f_5_9 = d["sex_age_white_f_5_9"]
            self.sex_age_white_f_10_14 = d["sex_age_white_f_10_14"]
            self.sex_age_white_f_15_17 = d["sex_age_white_f_15_17"]
            self.sex_age_white_f_18_19 = d["sex_age_white_f_18_19"]
            self.sex_age_white_f_20 = d["sex_age_white_f_20"]
            self.sex_age_white_f_21 = d["sex_age_white_f_21"]
            self.sex_age_white_f_22_24 = d["sex_age_white_f_22_24"]
            self.sex_age_white_f_25_29 = d["sex_age_white_f_25_29"]
            self.sex_age_white_f_30_34 = d["sex_age_white_f_30_34"]
            self.sex_age_white_f_35_39 = d["sex_age_white_f_35_39"]
            self.sex_age_white_f_40_44 = d["sex_age_white_f_40_44"]
            self.sex_age_white_f_45_49 = d["sex_age_white_f_45_49"]
            self.sex_age_white_f_50_54 = d["sex_age_white_f_50_54"]
            self.sex_age_white_f_55_59 = d["sex_age_white_f_55_59"]
            self.sex_age_white_f_60_61 = d["sex_age_white_f_60_61"]
            self.sex_age_white_f_62_64 = d["sex_age_white_f_62_64"]
            self.sex_age_white_f_65_66 = d["sex_age_white_f_65_66"]
            self.sex_age_white_f_67_69 = d["sex_age_white_f_67_69"]
            self.sex_age_white_f_70_74 = d["sex_age_white_f_70_74"]
            self.sex_age_white_f_75_79 = d["sex_age_white_f_75_79"]
            self.sex_age_white_f_80_84 = d["sex_age_white_f_80_84"]
            self.sex_age_white_f_85p = d["sex_age_white_f_85p"]
            self.sex_age_black_total = d["sex_age_black_total"]
            self.sex_age_black_m = d["sex_age_black_m"]
            self.sex_age_black_m_u5 = d["sex_age_black_m_u5"]
            self.sex_age_black_m_5_9 = d["sex_age_black_m_5_9"]
            self.sex_age_black_m_10_14 = d["sex_age_black_m_10_14"]
            self.sex_age_black_m_15_17 = d["sex_age_black_m_15_17"]
            self.sex_age_black_m_18_19 = d["sex_age_black_m_18_19"]
            self.sex_age_black_m_20 = d["sex_age_black_m_20"]
            self.sex_age_black_m_21 = d["sex_age_black_m_21"]
            self.sex_age_black_m_22_24 = d["sex_age_black_m_22_24"]
            self.sex_age_black_m_25_29 = d["sex_age_black_m_25_29"]
            self.sex_age_black_m_30_34 = d["sex_age_black_m_30_34"]
            self.sex_age_black_m_35_39 = d["sex_age_black_m_35_39"]
            self.sex_age_black_m_40_44 = d["sex_age_black_m_40_44"]
            self.sex_age_black_m_45_49 = d["sex_age_black_m_45_49"]
            self.sex_age_black_m_50_54 = d["sex_age_black_m_50_54"]
            self.sex_age_black_m_55_59 = d["sex_age_black_m_55_59"]
            self.sex_age_black_m_60_61 = d["sex_age_black_m_60_61"]
            self.sex_age_black_m_62_64 = d["sex_age_black_m_62_64"]
            self.sex_age_black_m_65_66 = d["sex_age_black_m_65_66"]
            self.sex_age_black_m_67_69 = d["sex_age_black_m_67_69"]
            self.sex_age_black_m_70_74 = d["sex_age_black_m_70_74"]
            self.sex_age_black_m_75_79 = d["sex_age_black_m_75_79"]
            self.sex_age_black_m_80_84 = d["sex_age_black_m_80_84"]
            self.sex_age_black_m_85p = d["sex_age_black_m_85p"]
            self.sex_age_black_f = d["sex_age_black_f"]
            self.sex_age_black_f_u5 = d["sex_age_black_f_u5"]
            self.sex_age_black_f_5_9 = d["sex_age_black_f_5_9"]
            self.sex_age_black_f_10_14 = d["sex_age_black_f_10_14"]
            self.sex_age_black_f_15_17 = d["sex_age_black_f_15_17"]
            self.sex_age_black_f_18_19 = d["sex_age_black_f_18_19"]
            self.sex_age_black_f_20 = d["sex_age_black_f_20"]
            self.sex_age_black_f_21 = d["sex_age_black_f_21"]
            self.sex_age_black_f_22_24 = d["sex_age_black_f_22_24"]
            self.sex_age_black_f_25_29 = d["sex_age_black_f_25_29"]
            self.sex_age_black_f_30_34 = d["sex_age_black_f_30_34"]
            self.sex_age_black_f_35_39 = d["sex_age_black_f_35_39"]
            self.sex_age_black_f_40_44 = d["sex_age_black_f_40_44"]
            self.sex_age_black_f_45_49 = d["sex_age_black_f_45_49"]
            self.sex_age_black_f_50_54 = d["sex_age_black_f_50_54"]
            self.sex_age_black_f_55_59 = d["sex_age_black_f_55_59"]
            self.sex_age_black_f_60_61 = d["sex_age_black_f_60_61"]
            self.sex_age_black_f_62_64 = d["sex_age_black_f_62_64"]
            self.sex_age_black_f_65_66 = d["sex_age_black_f_65_66"]
            self.sex_age_black_f_67_69 = d["sex_age_black_f_67_69"]
            self.sex_age_black_f_70_74 = d["sex_age_black_f_70_74"]
            self.sex_age_black_f_75_79 = d["sex_age_black_f_75_79"]
            self.sex_age_black_f_80_84 = d["sex_age_black_f_80_84"]
            self.sex_age_black_f_85p = d["sex_age_black_f_85p"]
            self.sex_age_natam_total = d["sex_age_natam_total"]
            self.sex_age_natam_m = d["sex_age_natam_m"]
            self.sex_age_natam_m_u5 = d["sex_age_natam_m_u5"]
            self.sex_age_natam_m_5_9 = d["sex_age_natam_m_5_9"]
            self.sex_age_natam_m_10_14 = d["sex_age_natam_m_10_14"]
            self.sex_age_natam_m_15_17 = d["sex_age_natam_m_15_17"]
            self.sex_age_natam_m_18_19 = d["sex_age_natam_m_18_19"]
            self.sex_age_natam_m_20 = d["sex_age_natam_m_20"]
            self.sex_age_natam_m_21 = d["sex_age_natam_m_21"]
            self.sex_age_natam_m_22_24 = d["sex_age_natam_m_22_24"]
            self.sex_age_natam_m_25_29 = d["sex_age_natam_m_25_29"]
            self.sex_age_natam_m_30_34 = d["sex_age_natam_m_30_34"]
            self.sex_age_natam_m_35_39 = d["sex_age_natam_m_35_39"]
            self.sex_age_natam_m_40_44 = d["sex_age_natam_m_40_44"]
            self.sex_age_natam_m_45_49 = d["sex_age_natam_m_45_49"]
            self.sex_age_natam_m_50_54 = d["sex_age_natam_m_50_54"]
            self.sex_age_natam_m_55_59 = d["sex_age_natam_m_55_59"]
            self.sex_age_natam_m_60_61 = d["sex_age_natam_m_60_61"]
            self.sex_age_natam_m_62_64 = d["sex_age_natam_m_62_64"]
            self.sex_age_natam_m_65_66 = d["sex_age_natam_m_65_66"]
            self.sex_age_natam_m_67_69 = d["sex_age_natam_m_67_69"]
            self.sex_age_natam_m_70_74 = d["sex_age_natam_m_70_74"]
            self.sex_age_natam_m_75_79 = d["sex_age_natam_m_75_79"]
            self.sex_age_natam_m_80_84 = d["sex_age_natam_m_80_84"]
            self.sex_age_natam_m_85p = d["sex_age_natam_m_85p"]
            self.sex_age_natam_f = d["sex_age_natam_f"]
            self.sex_age_natam_f_u5 = d["sex_age_natam_f_u5"]
            self.sex_age_natam_f_5_9 = d["sex_age_natam_f_5_9"]
            self.sex_age_natam_f_10_14 = d["sex_age_natam_f_10_14"]
            self.sex_age_natam_f_15_17 = d["sex_age_natam_f_15_17"]
            self.sex_age_natam_f_18_19 = d["sex_age_natam_f_18_19"]
            self.sex_age_natam_f_20 = d["sex_age_natam_f_20"]
            self.sex_age_natam_f_21 = d["sex_age_natam_f_21"]
            self.sex_age_natam_f_22_24 = d["sex_age_natam_f_22_24"]
            self.sex_age_natam_f_25_29 = d["sex_age_natam_f_25_29"]
            self.sex_age_natam_f_30_34 = d["sex_age_natam_f_30_34"]
            self.sex_age_natam_f_35_39 = d["sex_age_natam_f_35_39"]
            self.sex_age_natam_f_40_44 = d["sex_age_natam_f_40_44"]
            self.sex_age_natam_f_45_49 = d["sex_age_natam_f_45_49"]
            self.sex_age_natam_f_50_54 = d["sex_age_natam_f_50_54"]
            self.sex_age_natam_f_55_59 = d["sex_age_natam_f_55_59"]
            self.sex_age_natam_f_60_61 = d["sex_age_natam_f_60_61"]
            self.sex_age_natam_f_62_64 = d["sex_age_natam_f_62_64"]
            self.sex_age_natam_f_65_66 = d["sex_age_natam_f_65_66"]
            self.sex_age_natam_f_67_69 = d["sex_age_natam_f_67_69"]
            self.sex_age_natam_f_70_74 = d["sex_age_natam_f_70_74"]
            self.sex_age_natam_f_75_79 = d["sex_age_natam_f_75_79"]
            self.sex_age_natam_f_80_84 = d["sex_age_natam_f_80_84"]
            self.sex_age_natam_f_85p = d["sex_age_natam_f_85p"]
            self.sex_age_asian_total = d["sex_age_asian_total"]
            self.sex_age_asian_m = d["sex_age_asian_m"]
            self.sex_age_asian_m_u5 = d["sex_age_asian_m_u5"]
            self.sex_age_asian_m_5_9 = d["sex_age_asian_m_5_9"]
            self.sex_age_asian_m_10_14 = d["sex_age_asian_m_10_14"]
            self.sex_age_asian_m_15_17 = d["sex_age_asian_m_15_17"]
            self.sex_age_asian_m_18_19 = d["sex_age_asian_m_18_19"]
            self.sex_age_asian_m_20 = d["sex_age_asian_m_20"]
            self.sex_age_asian_m_21 = d["sex_age_asian_m_21"]
            self.sex_age_asian_m_22_24 = d["sex_age_asian_m_22_24"]
            self.sex_age_asian_m_25_29 = d["sex_age_asian_m_25_29"]
            self.sex_age_asian_m_30_34 = d["sex_age_asian_m_30_34"]
            self.sex_age_asian_m_35_39 = d["sex_age_asian_m_35_39"]
            self.sex_age_asian_m_40_44 = d["sex_age_asian_m_40_44"]
            self.sex_age_asian_m_45_49 = d["sex_age_asian_m_45_49"]
            self.sex_age_asian_m_50_54 = d["sex_age_asian_m_50_54"]
            self.sex_age_asian_m_55_59 = d["sex_age_asian_m_55_59"]
            self.sex_age_asian_m_60_61 = d["sex_age_asian_m_60_61"]
            self.sex_age_asian_m_62_64 = d["sex_age_asian_m_62_64"]
            self.sex_age_asian_m_65_66 = d["sex_age_asian_m_65_66"]
            self.sex_age_asian_m_67_69 = d["sex_age_asian_m_67_69"]
            self.sex_age_asian_m_70_74 = d["sex_age_asian_m_70_74"]
            self.sex_age_asian_m_75_79 = d["sex_age_asian_m_75_79"]
            self.sex_age_asian_m_80_84 = d["sex_age_asian_m_80_84"]
            self.sex_age_asian_m_85p = d["sex_age_asian_m_85p"]
            self.sex_age_asian_f = d["sex_age_asian_f"]
            self.sex_age_asian_f_u5 = d["sex_age_asian_f_u5"]
            self.sex_age_asian_f_5_9 = d["sex_age_asian_f_5_9"]
            self.sex_age_asian_f_10_14 = d["sex_age_asian_f_10_14"]
            self.sex_age_asian_f_15_17 = d["sex_age_asian_f_15_17"]
            self.sex_age_asian_f_18_19 = d["sex_age_asian_f_18_19"]
            self.sex_age_asian_f_20 = d["sex_age_asian_f_20"]
            self.sex_age_asian_f_21 = d["sex_age_asian_f_21"]
            self.sex_age_asian_f_22_24 = d["sex_age_asian_f_22_24"]
            self.sex_age_asian_f_25_29 = d["sex_age_asian_f_25_29"]
            self.sex_age_asian_f_30_34 = d["sex_age_asian_f_30_34"]
            self.sex_age_asian_f_35_39 = d["sex_age_asian_f_35_39"]
            self.sex_age_asian_f_40_44 = d["sex_age_asian_f_40_44"]
            self.sex_age_asian_f_45_49 = d["sex_age_asian_f_45_49"]
            self.sex_age_asian_f_50_54 = d["sex_age_asian_f_50_54"]
            self.sex_age_asian_f_55_59 = d["sex_age_asian_f_55_59"]
            self.sex_age_asian_f_60_61 = d["sex_age_asian_f_60_61"]
            self.sex_age_asian_f_62_64 = d["sex_age_asian_f_62_64"]
            self.sex_age_asian_f_65_66 = d["sex_age_asian_f_65_66"]
            self.sex_age_asian_f_67_69 = d["sex_age_asian_f_67_69"]
            self.sex_age_asian_f_70_74 = d["sex_age_asian_f_70_74"]
            self.sex_age_asian_f_75_79 = d["sex_age_asian_f_75_79"]
            self.sex_age_asian_f_80_84 = d["sex_age_asian_f_80_84"]
            self.sex_age_asian_f_85p = d["sex_age_asian_f_85p"]
            self.sex_age_isl_total = d["sex_age_isl_total"]
            self.sex_age_isl_m = d["sex_age_isl_m"]
            self.sex_age_isl_m_u5 = d["sex_age_isl_m_u5"]
            self.sex_age_hawaii_isl_m_5_9 = d["sex_age_hawaii_isl_m_5_9"]
            self.sex_age_hawaii_isl_m_10_14 = d["sex_age_hawaii_isl_m_10_14"]
            self.sex_age_hawaii_isl_m_15_17 = d["sex_age_hawaii_isl_m_15_17"]
            self.sex_age_hawaii_isl_m_18_19 = d["sex_age_hawaii_isl_m_18_19"]
            self.sex_age_hawaii_isl_m_20 = d["sex_age_hawaii_isl_m_20"]
            self.sex_age_hawaii_isl_m_21 = d["sex_age_hawaii_isl_m_21"]
            self.sex_age_hawaii_isl_m_22_24 = d["sex_age_hawaii_isl_m_22_24"]
            self.sex_age_hawaii_isl_m_25_29 = d["sex_age_hawaii_isl_m_25_29"]
            self.sex_age_hawaii_isl_m_30_34 = d["sex_age_hawaii_isl_m_30_34"]
            self.sex_age_hawaii_isl_m_35_39 = d["sex_age_hawaii_isl_m_35_39"]
            self.sex_age_hawaii_isl_m_40_44 = d["sex_age_hawaii_isl_m_40_44"]
            self.sex_age_hawaii_isl_m_45_49 = d["sex_age_hawaii_isl_m_45_49"]
            self.sex_age_hawaii_isl_m_50_54 = d["sex_age_hawaii_isl_m_50_54"]
            self.sex_age_hawaii_isl_m_55_59 = d["sex_age_hawaii_isl_m_55_59"]
            self.sex_age_hawaii_isl_m_60_61 = d["sex_age_hawaii_isl_m_60_61"]
            self.sex_age_hawaii_isl_m_62_64 = d["sex_age_hawaii_isl_m_62_64"]
            self.sex_age_hawaii_isl_m_65_66 = d["sex_age_hawaii_isl_m_65_66"]
            self.sex_age_hawaii_isl_m_67_69 = d["sex_age_hawaii_isl_m_67_69"]
            self.sex_age_hawaii_isl_m_70_74 = d["sex_age_hawaii_isl_m_70_74"]
            self.sex_age_hawaii_isl_m_75_79 = d["sex_age_hawaii_isl_m_75_79"]
            self.sex_age_hawaii_isl_m_80_84 = d["sex_age_hawaii_isl_m_80_84"]
            self.sex_age_hawaii_isl_m_85p = d["sex_age_hawaii_isl_m_85p"]
            self.sex_age_hawaii_isl_f = d["sex_age_hawaii_isl_f"]
            self.sex_age_hawaii_isl_f_u5 = d["sex_age_hawaii_isl_f_u5"]
            self.sex_age_hawaii_isl_f_5_9 = d["sex_age_hawaii_isl_f_5_9"]
            self.sex_age_hawaii_isl_f_10_14 = d["sex_age_hawaii_isl_f_10_14"]
            self.sex_age_hawaii_isl_f_15_17 = d["sex_age_hawaii_isl_f_15_17"]
            self.sex_age_hawaii_isl_f_18_19 = d["sex_age_hawaii_isl_f_18_19"]
            self.sex_age_hawaii_isl_f_20 = d["sex_age_hawaii_isl_f_20"]
            self.sex_age_hawaii_isl_f_21 = d["sex_age_hawaii_isl_f_21"]
            self.sex_age_hawaii_isl_f_22_24 = d["sex_age_hawaii_isl_f_22_24"]
            self.sex_age_hawaii_isl_f_25_29 = d["sex_age_hawaii_isl_f_25_29"]
            self.sex_age_hawaii_isl_f_30_34 = d["sex_age_hawaii_isl_f_30_34"]
            self.sex_age_hawaii_isl_f_35_39 = d["sex_age_hawaii_isl_f_35_39"]
            self.sex_age_hawaii_isl_f_40_44 = d["sex_age_hawaii_isl_f_40_44"]
            self.sex_age_hawaii_isl_f_45_49 = d["sex_age_hawaii_isl_f_45_49"]
            self.sex_age_hawaii_isl_f_50_54 = d["sex_age_hawaii_isl_f_50_54"]
            self.sex_age_hawaii_isl_f_55_59 = d["sex_age_hawaii_isl_f_55_59"]
            self.sex_age_hawaii_isl_f_60_61 = d["sex_age_hawaii_isl_f_60_61"]
            self.sex_age_hawaii_isl_f_62_64 = d["sex_age_hawaii_isl_f_62_64"]
            self.sex_age_hawaii_isl_f_65_66 = d["sex_age_hawaii_isl_f_65_66"]
            self.sex_age_hawaii_isl_f_67_69 = d["sex_age_hawaii_isl_f_67_69"]
            self.sex_age_hawaii_isl_f_70_74 = d["sex_age_hawaii_isl_f_70_74"]
            self.sex_age_hawaii_isl_f_75_79 = d["sex_age_hawaii_isl_f_75_79"]
            self.sex_age_hawaii_isl_f_80_84 = d["sex_age_hawaii_isl_f_80_84"]
            self.sex_age_hawaii_isl_f_85p = d["sex_age_hawaii_isl_f_85p"]


class City():
    "A City"
    def __init__(self, d=None):
        self.name = ""
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        if d is not None:
            self.name = d["name"]
            if d["lat"]:
                self.lat = decimal.Decimal(d["lat"])
            if d["lon"]:
                self.lon = decimal.Decimal(d["lon"])


class SpecDocs():
    "File Spec Documentation"
    def __init__(self, d=None):
        self.col_name = ""
        self.col_title = ""
        self.col_descr = ""
        if d is not None:
            self.col_name = d["col_name"]
            self.col_title = d["col_title"]
            self.col_descr = d["col_descr"]


class GeoLatLon():
    "A geocoded latitude/longitude location"
    def __init__(self, d=None):
        self.lat = decimal.Decimal(0)
        self.lon = decimal.Decimal(0)
        self.descr = ""
        self.block_code = ""
        self.tract_code = ""
        self.county_code = ""
        self.county_name = ""
        self.state_code = ""
        self.state_abbrev = ""
        self.state_name = ""
        if d is not None:
            if d["lat"]:
                self.lat = decimal.Decimal(d["lat"])
            if d["lon"]:    
                self.lon = decimal.Decimal(d["lon"])
            self.descr = d["descr"]
            self.block_code = d["block_code"]
            self.tract_code = d["tract_code"]
            self.county_code = d["county_code"]
            self.county_name = d["county_name"]
            self.state_code = d["state_code"]
            self.state_abbrev = d["state_abbrev"]
            self.state_name = d["state_name"]


class RevgeoAddr():
    "A reverse geocoded address"
    def __init__(self, d=None):
        self.address = ""
        self.distance = decimal.Decimal(0)
        if d is not None:
            self.address = d["address"]
            if d["distance"]:
                self.distance = decimal.Decimal(d["distance"])


class Client():
    "API Client"

    def __init__(self, username=None, password=None, url_base=None):
        # If these are None, requests will look in .netrc for auth
        self.username = username
        self.password = password
        self.url_base = url_base
        if self.url_base is None:
            self.url_base = URL_BASE


    def get(self, url):
        "Call an API GET endpoint"
        full_url = self.url_base + url
        r = None
        try:
            if self.username:
                r = requests.get(full_url, auth=(self.username, self.password))
            else:
                r = requests.get(full_url) # Uses .netrc
            r.raise_for_status()
            return r.json()
        except requests.exceptions.RequestException as e: 
            raise e
    

    def get_states(self):
        "Get a list of US states"
        j = self.get("/census2010/states")
        states = []
        for d in j:
            states.append(CensusState(d))
        return states


    def get_counties(self, state_code):
        "Get the counties in one state"
        j = self.get("/census2010/counties/" + state_code)
        counties = []
        for d in j:
            counties.append(CensusCounty(d))
        return counties


    def get_tracts(self, state_code, county_code):
        "Get the census tracts in one county"
        j = self.get(
            "/census2010/tracts/{}/{}".format(state_code, county_code))
        tracts = []
        for d in j:
            tracts.append(CensusTract(d))
        return tracts


    def get_blocks(self, state_code, county_code, tract_code):
        "Get the census blocks in one tract"
        j = self.get(
            "/census2010/blocks/{}/{}/{}".format(
                state_code, county_code, tract_code))
        blocks = []
        for d in j:
            blocks.append(CensusBlock(d))
        return blocks


    def get_tract_profile(self, state_code, county_code, tract_code):
        "Get the demographic profile for the census tract"
        j = self.get(
            "/census2010/dp/{}/{}/{}".format(
                state_code, county_code, tract_code))
        dp = TractDemographicProfile(j[0])
        return dp


    def get_basic_county(self, state_code, county_code):
        "Get basic demographics for the county"
        j = self.get(
            "/census2010/sf1basic/state/{}/county/{}".format(
                state_code, county_code))
        bd = BasicDemographics(j[0])
        return bd


    def get_zctas(self, state_code):
        "Get the zctas in one state"
        j = self.get("/census2010/zcta5/" + state_code)
        zctas = []
        for d in j:
            zctas.append(Zcta(d))
        return zctas


    def get_basic_tract(self, state_code, county_code, tract_code):
        "Get basic demographics for the tract"
        j = self.get(
            "/census2010/sf1basic/state/{}/county/{}/tract/{}".format(
                state_code, county_code, tract_code))
        bd = BasicDemographics(j[0])
        return bd


    def get_basic_block(self, state_code, county_code, tract_code, block_code):
        "Get basic demographics for the block"
        j = self.get(
            "/census2010/sf1basic/state/{}/county/{}/tract/{}/block/{}".format(
                state_code, county_code, tract_code, block_code))
        bd = BasicDemographics(j[0])
        return bd


    def get_cities(self, state_abbrev):
        "Get the cities in one state"
        j = self.get("/cities/" + state_abbrev)
        cities = []
        for d in j:
            cities.append(City(d))
        return cities


    def geocode(self, address):
        "Geocode a mailing address"
        j = self.get("/geocode/" + address)
        latlon = GeoLatLon(j)
        return latlon


    def revgeocode(self, lat, lon):
        "Reverse geocode coordinates to find the closest address"
        j = self.get("/revgeocode/{}/{}".format(str(lat), str(lon)))
        return RevgeoAddr(j)


    def get_sf1_docs(self, file_num):
        "Get docs for an SF1 File. 01, 03, 04, 05, 06, 07."
        j = self.get("/census2010/sf1/{}/docs".format(file_num))
        docs = []
        for d in j:
            docs.append(SpecDocs(d))
        return docs


    def get_sf101(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 01"
        j = self.get(
            "/census2010/sf1/01/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF101(j[0])
        return sf


    def get_sf103(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 03"
        j = self.get(
            "/census2010/sf1/03/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF103(j[0])
        return sf
    

    def get_sf104(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 04"
        j = self.get(
            "/census2010/sf1/04/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF104(j[0])
        return sf
    

    def get_sf105(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 05"
        j = self.get(
            "/census2010/sf1/05/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF105(j[0])
        return sf
    

    def get_sf106(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 06"
        j = self.get(
            "/census2010/sf1/06/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF106(j[0])
        return sf
    

    def get_sf107(self, state_code, county_code, tract_code, block_code):
        "Get data from the 2010 census SF1 file 07"
        j = self.get(
            "/census2010/sf1/07/{}/{}/{}/{}".format(
                state_code, county_code, tract_code, block_code))
        sf = SF107(j[0])
        return sf
    